# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MaterialClassificationResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'material_classification_reference_number': 'str',
        'material_classification_coordinates': 'object',
        'material_classification_classification': 'MaterialClassificationClassificationResponse',
        'material_classification_classification_string': 'str',
        'hazardous_material_type': 'list[HazardousMaterialTypeResponse]',
        'hazardous_material_type_string': 'list[str]',
        'hazardous_material_type_other_description': 'str',
        'layer_affected': 'list[LayerAffectedResponse]',
        'layer_affected_string': 'list[str]',
        'location_types': 'list[LocationTypeResponse]',
        'location_types_string': 'list[str]',
        'sample_date': 'datetime',
        'location_description': 'str',
        'date_created': 'datetime',
        'ha_swa_code': 'str',
        'ha_organisation_name': 'str',
        'usrn': 'float',
        'street_name': 'str',
        'town': 'str',
        'area_name': 'str',
        'raised_by_swa_code': 'str',
        'raised_by_organisation_name': 'str',
        'file': 'AllOfMaterialClassificationResponseFile'
    }

    attribute_map = {
        'material_classification_reference_number': 'material_classification_reference_number',
        'material_classification_coordinates': 'material_classification_coordinates',
        'material_classification_classification': 'material_classification_classification',
        'material_classification_classification_string': 'material_classification_classification_string',
        'hazardous_material_type': 'hazardous_material_type',
        'hazardous_material_type_string': 'hazardous_material_type_string',
        'hazardous_material_type_other_description': 'hazardous_material_type_other_description',
        'layer_affected': 'layer_affected',
        'layer_affected_string': 'layer_affected_string',
        'location_types': 'location_types',
        'location_types_string': 'location_types_string',
        'sample_date': 'sample_date',
        'location_description': 'location_description',
        'date_created': 'date_created',
        'ha_swa_code': 'ha_swa_code',
        'ha_organisation_name': 'ha_organisation_name',
        'usrn': 'usrn',
        'street_name': 'street_name',
        'town': 'town',
        'area_name': 'area_name',
        'raised_by_swa_code': 'raised_by_swa_code',
        'raised_by_organisation_name': 'raised_by_organisation_name',
        'file': 'file'
    }

    def __init__(self, material_classification_reference_number=None, material_classification_coordinates=None, material_classification_classification=None, material_classification_classification_string=None, hazardous_material_type=None, hazardous_material_type_string=None, hazardous_material_type_other_description=None, layer_affected=None, layer_affected_string=None, location_types=None, location_types_string=None, sample_date=None, location_description=None, date_created=None, ha_swa_code=None, ha_organisation_name=None, usrn=None, street_name=None, town=None, area_name=None, raised_by_swa_code=None, raised_by_organisation_name=None, file=None):  # noqa: E501
        """MaterialClassificationResponse - a model defined in Swagger"""  # noqa: E501
        self._material_classification_reference_number = None
        self._material_classification_coordinates = None
        self._material_classification_classification = None
        self._material_classification_classification_string = None
        self._hazardous_material_type = None
        self._hazardous_material_type_string = None
        self._hazardous_material_type_other_description = None
        self._layer_affected = None
        self._layer_affected_string = None
        self._location_types = None
        self._location_types_string = None
        self._sample_date = None
        self._location_description = None
        self._date_created = None
        self._ha_swa_code = None
        self._ha_organisation_name = None
        self._usrn = None
        self._street_name = None
        self._town = None
        self._area_name = None
        self._raised_by_swa_code = None
        self._raised_by_organisation_name = None
        self._file = None
        self.discriminator = None
        self.material_classification_reference_number = material_classification_reference_number
        self.material_classification_coordinates = material_classification_coordinates
        self.material_classification_classification = material_classification_classification
        self.material_classification_classification_string = material_classification_classification_string
        if hazardous_material_type is not None:
            self.hazardous_material_type = hazardous_material_type
        if hazardous_material_type_string is not None:
            self.hazardous_material_type_string = hazardous_material_type_string
        if hazardous_material_type_other_description is not None:
            self.hazardous_material_type_other_description = hazardous_material_type_other_description
        self.layer_affected = layer_affected
        self.layer_affected_string = layer_affected_string
        self.location_types = location_types
        self.location_types_string = location_types_string
        self.sample_date = sample_date
        self.location_description = location_description
        self.date_created = date_created
        self.ha_swa_code = ha_swa_code
        self.ha_organisation_name = ha_organisation_name
        self.usrn = usrn
        self.street_name = street_name
        if town is not None:
            self.town = town
        if area_name is not None:
            self.area_name = area_name
        self.raised_by_swa_code = raised_by_swa_code
        self.raised_by_organisation_name = raised_by_organisation_name
        if file is not None:
            self.file = file

    @property
    def material_classification_reference_number(self):
        """Gets the material_classification_reference_number of this MaterialClassificationResponse.  # noqa: E501


        :return: The material_classification_reference_number of this MaterialClassificationResponse.  # noqa: E501
        :rtype: str
        """
        return self._material_classification_reference_number

    @material_classification_reference_number.setter
    def material_classification_reference_number(self, material_classification_reference_number):
        """Sets the material_classification_reference_number of this MaterialClassificationResponse.


        :param material_classification_reference_number: The material_classification_reference_number of this MaterialClassificationResponse.  # noqa: E501
        :type: str
        """
        if material_classification_reference_number is None:
            raise ValueError("Invalid value for `material_classification_reference_number`, must not be `None`")  # noqa: E501

        self._material_classification_reference_number = material_classification_reference_number

    @property
    def material_classification_coordinates(self):
        """Gets the material_classification_coordinates of this MaterialClassificationResponse.  # noqa: E501


        :return: The material_classification_coordinates of this MaterialClassificationResponse.  # noqa: E501
        :rtype: object
        """
        return self._material_classification_coordinates

    @material_classification_coordinates.setter
    def material_classification_coordinates(self, material_classification_coordinates):
        """Sets the material_classification_coordinates of this MaterialClassificationResponse.


        :param material_classification_coordinates: The material_classification_coordinates of this MaterialClassificationResponse.  # noqa: E501
        :type: object
        """
        if material_classification_coordinates is None:
            raise ValueError("Invalid value for `material_classification_coordinates`, must not be `None`")  # noqa: E501

        self._material_classification_coordinates = material_classification_coordinates

    @property
    def material_classification_classification(self):
        """Gets the material_classification_classification of this MaterialClassificationResponse.  # noqa: E501


        :return: The material_classification_classification of this MaterialClassificationResponse.  # noqa: E501
        :rtype: MaterialClassificationClassificationResponse
        """
        return self._material_classification_classification

    @material_classification_classification.setter
    def material_classification_classification(self, material_classification_classification):
        """Sets the material_classification_classification of this MaterialClassificationResponse.


        :param material_classification_classification: The material_classification_classification of this MaterialClassificationResponse.  # noqa: E501
        :type: MaterialClassificationClassificationResponse
        """
        if material_classification_classification is None:
            raise ValueError("Invalid value for `material_classification_classification`, must not be `None`")  # noqa: E501

        self._material_classification_classification = material_classification_classification

    @property
    def material_classification_classification_string(self):
        """Gets the material_classification_classification_string of this MaterialClassificationResponse.  # noqa: E501


        :return: The material_classification_classification_string of this MaterialClassificationResponse.  # noqa: E501
        :rtype: str
        """
        return self._material_classification_classification_string

    @material_classification_classification_string.setter
    def material_classification_classification_string(self, material_classification_classification_string):
        """Sets the material_classification_classification_string of this MaterialClassificationResponse.


        :param material_classification_classification_string: The material_classification_classification_string of this MaterialClassificationResponse.  # noqa: E501
        :type: str
        """
        if material_classification_classification_string is None:
            raise ValueError("Invalid value for `material_classification_classification_string`, must not be `None`")  # noqa: E501

        self._material_classification_classification_string = material_classification_classification_string

    @property
    def hazardous_material_type(self):
        """Gets the hazardous_material_type of this MaterialClassificationResponse.  # noqa: E501


        :return: The hazardous_material_type of this MaterialClassificationResponse.  # noqa: E501
        :rtype: list[HazardousMaterialTypeResponse]
        """
        return self._hazardous_material_type

    @hazardous_material_type.setter
    def hazardous_material_type(self, hazardous_material_type):
        """Sets the hazardous_material_type of this MaterialClassificationResponse.


        :param hazardous_material_type: The hazardous_material_type of this MaterialClassificationResponse.  # noqa: E501
        :type: list[HazardousMaterialTypeResponse]
        """

        self._hazardous_material_type = hazardous_material_type

    @property
    def hazardous_material_type_string(self):
        """Gets the hazardous_material_type_string of this MaterialClassificationResponse.  # noqa: E501


        :return: The hazardous_material_type_string of this MaterialClassificationResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._hazardous_material_type_string

    @hazardous_material_type_string.setter
    def hazardous_material_type_string(self, hazardous_material_type_string):
        """Sets the hazardous_material_type_string of this MaterialClassificationResponse.


        :param hazardous_material_type_string: The hazardous_material_type_string of this MaterialClassificationResponse.  # noqa: E501
        :type: list[str]
        """

        self._hazardous_material_type_string = hazardous_material_type_string

    @property
    def hazardous_material_type_other_description(self):
        """Gets the hazardous_material_type_other_description of this MaterialClassificationResponse.  # noqa: E501


        :return: The hazardous_material_type_other_description of this MaterialClassificationResponse.  # noqa: E501
        :rtype: str
        """
        return self._hazardous_material_type_other_description

    @hazardous_material_type_other_description.setter
    def hazardous_material_type_other_description(self, hazardous_material_type_other_description):
        """Sets the hazardous_material_type_other_description of this MaterialClassificationResponse.


        :param hazardous_material_type_other_description: The hazardous_material_type_other_description of this MaterialClassificationResponse.  # noqa: E501
        :type: str
        """

        self._hazardous_material_type_other_description = hazardous_material_type_other_description

    @property
    def layer_affected(self):
        """Gets the layer_affected of this MaterialClassificationResponse.  # noqa: E501


        :return: The layer_affected of this MaterialClassificationResponse.  # noqa: E501
        :rtype: list[LayerAffectedResponse]
        """
        return self._layer_affected

    @layer_affected.setter
    def layer_affected(self, layer_affected):
        """Sets the layer_affected of this MaterialClassificationResponse.


        :param layer_affected: The layer_affected of this MaterialClassificationResponse.  # noqa: E501
        :type: list[LayerAffectedResponse]
        """
        if layer_affected is None:
            raise ValueError("Invalid value for `layer_affected`, must not be `None`")  # noqa: E501

        self._layer_affected = layer_affected

    @property
    def layer_affected_string(self):
        """Gets the layer_affected_string of this MaterialClassificationResponse.  # noqa: E501


        :return: The layer_affected_string of this MaterialClassificationResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._layer_affected_string

    @layer_affected_string.setter
    def layer_affected_string(self, layer_affected_string):
        """Sets the layer_affected_string of this MaterialClassificationResponse.


        :param layer_affected_string: The layer_affected_string of this MaterialClassificationResponse.  # noqa: E501
        :type: list[str]
        """
        if layer_affected_string is None:
            raise ValueError("Invalid value for `layer_affected_string`, must not be `None`")  # noqa: E501

        self._layer_affected_string = layer_affected_string

    @property
    def location_types(self):
        """Gets the location_types of this MaterialClassificationResponse.  # noqa: E501


        :return: The location_types of this MaterialClassificationResponse.  # noqa: E501
        :rtype: list[LocationTypeResponse]
        """
        return self._location_types

    @location_types.setter
    def location_types(self, location_types):
        """Sets the location_types of this MaterialClassificationResponse.


        :param location_types: The location_types of this MaterialClassificationResponse.  # noqa: E501
        :type: list[LocationTypeResponse]
        """
        if location_types is None:
            raise ValueError("Invalid value for `location_types`, must not be `None`")  # noqa: E501

        self._location_types = location_types

    @property
    def location_types_string(self):
        """Gets the location_types_string of this MaterialClassificationResponse.  # noqa: E501


        :return: The location_types_string of this MaterialClassificationResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._location_types_string

    @location_types_string.setter
    def location_types_string(self, location_types_string):
        """Sets the location_types_string of this MaterialClassificationResponse.


        :param location_types_string: The location_types_string of this MaterialClassificationResponse.  # noqa: E501
        :type: list[str]
        """
        if location_types_string is None:
            raise ValueError("Invalid value for `location_types_string`, must not be `None`")  # noqa: E501

        self._location_types_string = location_types_string

    @property
    def sample_date(self):
        """Gets the sample_date of this MaterialClassificationResponse.  # noqa: E501


        :return: The sample_date of this MaterialClassificationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._sample_date

    @sample_date.setter
    def sample_date(self, sample_date):
        """Sets the sample_date of this MaterialClassificationResponse.


        :param sample_date: The sample_date of this MaterialClassificationResponse.  # noqa: E501
        :type: datetime
        """
        if sample_date is None:
            raise ValueError("Invalid value for `sample_date`, must not be `None`")  # noqa: E501

        self._sample_date = sample_date

    @property
    def location_description(self):
        """Gets the location_description of this MaterialClassificationResponse.  # noqa: E501


        :return: The location_description of this MaterialClassificationResponse.  # noqa: E501
        :rtype: str
        """
        return self._location_description

    @location_description.setter
    def location_description(self, location_description):
        """Sets the location_description of this MaterialClassificationResponse.


        :param location_description: The location_description of this MaterialClassificationResponse.  # noqa: E501
        :type: str
        """
        if location_description is None:
            raise ValueError("Invalid value for `location_description`, must not be `None`")  # noqa: E501

        self._location_description = location_description

    @property
    def date_created(self):
        """Gets the date_created of this MaterialClassificationResponse.  # noqa: E501


        :return: The date_created of this MaterialClassificationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this MaterialClassificationResponse.


        :param date_created: The date_created of this MaterialClassificationResponse.  # noqa: E501
        :type: datetime
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def ha_swa_code(self):
        """Gets the ha_swa_code of this MaterialClassificationResponse.  # noqa: E501


        :return: The ha_swa_code of this MaterialClassificationResponse.  # noqa: E501
        :rtype: str
        """
        return self._ha_swa_code

    @ha_swa_code.setter
    def ha_swa_code(self, ha_swa_code):
        """Sets the ha_swa_code of this MaterialClassificationResponse.


        :param ha_swa_code: The ha_swa_code of this MaterialClassificationResponse.  # noqa: E501
        :type: str
        """
        if ha_swa_code is None:
            raise ValueError("Invalid value for `ha_swa_code`, must not be `None`")  # noqa: E501

        self._ha_swa_code = ha_swa_code

    @property
    def ha_organisation_name(self):
        """Gets the ha_organisation_name of this MaterialClassificationResponse.  # noqa: E501


        :return: The ha_organisation_name of this MaterialClassificationResponse.  # noqa: E501
        :rtype: str
        """
        return self._ha_organisation_name

    @ha_organisation_name.setter
    def ha_organisation_name(self, ha_organisation_name):
        """Sets the ha_organisation_name of this MaterialClassificationResponse.


        :param ha_organisation_name: The ha_organisation_name of this MaterialClassificationResponse.  # noqa: E501
        :type: str
        """
        if ha_organisation_name is None:
            raise ValueError("Invalid value for `ha_organisation_name`, must not be `None`")  # noqa: E501

        self._ha_organisation_name = ha_organisation_name

    @property
    def usrn(self):
        """Gets the usrn of this MaterialClassificationResponse.  # noqa: E501


        :return: The usrn of this MaterialClassificationResponse.  # noqa: E501
        :rtype: float
        """
        return self._usrn

    @usrn.setter
    def usrn(self, usrn):
        """Sets the usrn of this MaterialClassificationResponse.


        :param usrn: The usrn of this MaterialClassificationResponse.  # noqa: E501
        :type: float
        """
        if usrn is None:
            raise ValueError("Invalid value for `usrn`, must not be `None`")  # noqa: E501

        self._usrn = usrn

    @property
    def street_name(self):
        """Gets the street_name of this MaterialClassificationResponse.  # noqa: E501


        :return: The street_name of this MaterialClassificationResponse.  # noqa: E501
        :rtype: str
        """
        return self._street_name

    @street_name.setter
    def street_name(self, street_name):
        """Sets the street_name of this MaterialClassificationResponse.


        :param street_name: The street_name of this MaterialClassificationResponse.  # noqa: E501
        :type: str
        """
        if street_name is None:
            raise ValueError("Invalid value for `street_name`, must not be `None`")  # noqa: E501

        self._street_name = street_name

    @property
    def town(self):
        """Gets the town of this MaterialClassificationResponse.  # noqa: E501


        :return: The town of this MaterialClassificationResponse.  # noqa: E501
        :rtype: str
        """
        return self._town

    @town.setter
    def town(self, town):
        """Sets the town of this MaterialClassificationResponse.


        :param town: The town of this MaterialClassificationResponse.  # noqa: E501
        :type: str
        """

        self._town = town

    @property
    def area_name(self):
        """Gets the area_name of this MaterialClassificationResponse.  # noqa: E501


        :return: The area_name of this MaterialClassificationResponse.  # noqa: E501
        :rtype: str
        """
        return self._area_name

    @area_name.setter
    def area_name(self, area_name):
        """Sets the area_name of this MaterialClassificationResponse.


        :param area_name: The area_name of this MaterialClassificationResponse.  # noqa: E501
        :type: str
        """

        self._area_name = area_name

    @property
    def raised_by_swa_code(self):
        """Gets the raised_by_swa_code of this MaterialClassificationResponse.  # noqa: E501


        :return: The raised_by_swa_code of this MaterialClassificationResponse.  # noqa: E501
        :rtype: str
        """
        return self._raised_by_swa_code

    @raised_by_swa_code.setter
    def raised_by_swa_code(self, raised_by_swa_code):
        """Sets the raised_by_swa_code of this MaterialClassificationResponse.


        :param raised_by_swa_code: The raised_by_swa_code of this MaterialClassificationResponse.  # noqa: E501
        :type: str
        """
        if raised_by_swa_code is None:
            raise ValueError("Invalid value for `raised_by_swa_code`, must not be `None`")  # noqa: E501

        self._raised_by_swa_code = raised_by_swa_code

    @property
    def raised_by_organisation_name(self):
        """Gets the raised_by_organisation_name of this MaterialClassificationResponse.  # noqa: E501


        :return: The raised_by_organisation_name of this MaterialClassificationResponse.  # noqa: E501
        :rtype: str
        """
        return self._raised_by_organisation_name

    @raised_by_organisation_name.setter
    def raised_by_organisation_name(self, raised_by_organisation_name):
        """Sets the raised_by_organisation_name of this MaterialClassificationResponse.


        :param raised_by_organisation_name: The raised_by_organisation_name of this MaterialClassificationResponse.  # noqa: E501
        :type: str
        """
        if raised_by_organisation_name is None:
            raise ValueError("Invalid value for `raised_by_organisation_name`, must not be `None`")  # noqa: E501

        self._raised_by_organisation_name = raised_by_organisation_name

    @property
    def file(self):
        """Gets the file of this MaterialClassificationResponse.  # noqa: E501


        :return: The file of this MaterialClassificationResponse.  # noqa: E501
        :rtype: AllOfMaterialClassificationResponseFile
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this MaterialClassificationResponse.


        :param file: The file of this MaterialClassificationResponse.  # noqa: E501
        :type: AllOfMaterialClassificationResponseFile
        """

        self._file = file

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MaterialClassificationResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MaterialClassificationResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ForwardPlanResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'work_reference_number': 'str',
        'forward_plan_reference_number': 'str',
        'start_date': 'datetime',
        'end_date': 'datetime',
        'forward_plan_status': 'ForwardPlanStatusResponse',
        'forward_plan_status_string': 'str',
        'promoter_organisation': 'str',
        'promoter_swa_code': 'str',
        'promoter_contact_details': 'str',
        'highway_authority': 'str',
        'highway_authority_swa_code': 'str',
        'workstream_prefix': 'str',
        'works_coordinates': 'object',
        'street_name': 'str',
        'town': 'str',
        'area_name': 'str',
        'usrn': 'float',
        'road_category': 'float',
        'date_created': 'datetime',
        'works_location_description': 'str',
        'description_of_work': 'str',
        'project_reference_number': 'str',
        'traffic_management_type': 'AllOfForwardPlanResponseTrafficManagementType',
        'traffic_management_type_string': 'str',
        'additional_info': 'str',
        'forward_plan_asds': 'list[PermitASDResponse]',
        'cancelled_reason': 'str',
        'hs2_in_act_limits': 'bool',
        'hs2_consultation_requested_response_date': 'datetime',
        'hs2_highway_exemption': 'AllOfForwardPlanResponseHs2HighwayExemption',
        'hs2_highway_exemption_string': 'str',
        'hs2_works_type': 'AllOfForwardPlanResponseHs2WorksType',
        'hs2_works_type_string': 'str'
    }

    attribute_map = {
        'work_reference_number': 'work_reference_number',
        'forward_plan_reference_number': 'forward_plan_reference_number',
        'start_date': 'start_date',
        'end_date': 'end_date',
        'forward_plan_status': 'forward_plan_status',
        'forward_plan_status_string': 'forward_plan_status_string',
        'promoter_organisation': 'promoter_organisation',
        'promoter_swa_code': 'promoter_swa_code',
        'promoter_contact_details': 'promoter_contact_details',
        'highway_authority': 'highway_authority',
        'highway_authority_swa_code': 'highway_authority_swa_code',
        'workstream_prefix': 'workstream_prefix',
        'works_coordinates': 'works_coordinates',
        'street_name': 'street_name',
        'town': 'town',
        'area_name': 'area_name',
        'usrn': 'usrn',
        'road_category': 'road_category',
        'date_created': 'date_created',
        'works_location_description': 'works_location_description',
        'description_of_work': 'description_of_work',
        'project_reference_number': 'project_reference_number',
        'traffic_management_type': 'traffic_management_type',
        'traffic_management_type_string': 'traffic_management_type_string',
        'additional_info': 'additional_info',
        'forward_plan_asds': 'forward_plan_asds',
        'cancelled_reason': 'cancelled_reason',
        'hs2_in_act_limits': 'hs2_in_act_limits',
        'hs2_consultation_requested_response_date': 'hs2_consultation_requested_response_date',
        'hs2_highway_exemption': 'hs2_highway_exemption',
        'hs2_highway_exemption_string': 'hs2_highway_exemption_string',
        'hs2_works_type': 'hs2_works_type',
        'hs2_works_type_string': 'hs2_works_type_string'
    }

    def __init__(self, work_reference_number=None, forward_plan_reference_number=None, start_date=None, end_date=None, forward_plan_status=None, forward_plan_status_string=None, promoter_organisation=None, promoter_swa_code=None, promoter_contact_details=None, highway_authority=None, highway_authority_swa_code=None, workstream_prefix=None, works_coordinates=None, street_name=None, town=None, area_name=None, usrn=None, road_category=None, date_created=None, works_location_description=None, description_of_work=None, project_reference_number=None, traffic_management_type=None, traffic_management_type_string=None, additional_info=None, forward_plan_asds=None, cancelled_reason=None, hs2_in_act_limits=None, hs2_consultation_requested_response_date=None, hs2_highway_exemption=None, hs2_highway_exemption_string=None, hs2_works_type=None, hs2_works_type_string=None):  # noqa: E501
        """ForwardPlanResponse - a model defined in Swagger"""  # noqa: E501
        self._work_reference_number = None
        self._forward_plan_reference_number = None
        self._start_date = None
        self._end_date = None
        self._forward_plan_status = None
        self._forward_plan_status_string = None
        self._promoter_organisation = None
        self._promoter_swa_code = None
        self._promoter_contact_details = None
        self._highway_authority = None
        self._highway_authority_swa_code = None
        self._workstream_prefix = None
        self._works_coordinates = None
        self._street_name = None
        self._town = None
        self._area_name = None
        self._usrn = None
        self._road_category = None
        self._date_created = None
        self._works_location_description = None
        self._description_of_work = None
        self._project_reference_number = None
        self._traffic_management_type = None
        self._traffic_management_type_string = None
        self._additional_info = None
        self._forward_plan_asds = None
        self._cancelled_reason = None
        self._hs2_in_act_limits = None
        self._hs2_consultation_requested_response_date = None
        self._hs2_highway_exemption = None
        self._hs2_highway_exemption_string = None
        self._hs2_works_type = None
        self._hs2_works_type_string = None
        self.discriminator = None
        self.work_reference_number = work_reference_number
        self.forward_plan_reference_number = forward_plan_reference_number
        self.start_date = start_date
        self.end_date = end_date
        self.forward_plan_status = forward_plan_status
        self.forward_plan_status_string = forward_plan_status_string
        self.promoter_organisation = promoter_organisation
        self.promoter_swa_code = promoter_swa_code
        self.promoter_contact_details = promoter_contact_details
        self.highway_authority = highway_authority
        self.highway_authority_swa_code = highway_authority_swa_code
        self.workstream_prefix = workstream_prefix
        self.works_coordinates = works_coordinates
        self.street_name = street_name
        if town is not None:
            self.town = town
        if area_name is not None:
            self.area_name = area_name
        self.usrn = usrn
        self.road_category = road_category
        self.date_created = date_created
        self.works_location_description = works_location_description
        self.description_of_work = description_of_work
        if project_reference_number is not None:
            self.project_reference_number = project_reference_number
        if traffic_management_type is not None:
            self.traffic_management_type = traffic_management_type
        if traffic_management_type_string is not None:
            self.traffic_management_type_string = traffic_management_type_string
        if additional_info is not None:
            self.additional_info = additional_info
        if forward_plan_asds is not None:
            self.forward_plan_asds = forward_plan_asds
        if cancelled_reason is not None:
            self.cancelled_reason = cancelled_reason
        if hs2_in_act_limits is not None:
            self.hs2_in_act_limits = hs2_in_act_limits
        if hs2_consultation_requested_response_date is not None:
            self.hs2_consultation_requested_response_date = hs2_consultation_requested_response_date
        if hs2_highway_exemption is not None:
            self.hs2_highway_exemption = hs2_highway_exemption
        if hs2_highway_exemption_string is not None:
            self.hs2_highway_exemption_string = hs2_highway_exemption_string
        if hs2_works_type is not None:
            self.hs2_works_type = hs2_works_type
        if hs2_works_type_string is not None:
            self.hs2_works_type_string = hs2_works_type_string

    @property
    def work_reference_number(self):
        """Gets the work_reference_number of this ForwardPlanResponse.  # noqa: E501


        :return: The work_reference_number of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._work_reference_number

    @work_reference_number.setter
    def work_reference_number(self, work_reference_number):
        """Sets the work_reference_number of this ForwardPlanResponse.


        :param work_reference_number: The work_reference_number of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if work_reference_number is None:
            raise ValueError("Invalid value for `work_reference_number`, must not be `None`")  # noqa: E501

        self._work_reference_number = work_reference_number

    @property
    def forward_plan_reference_number(self):
        """Gets the forward_plan_reference_number of this ForwardPlanResponse.  # noqa: E501


        :return: The forward_plan_reference_number of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._forward_plan_reference_number

    @forward_plan_reference_number.setter
    def forward_plan_reference_number(self, forward_plan_reference_number):
        """Sets the forward_plan_reference_number of this ForwardPlanResponse.


        :param forward_plan_reference_number: The forward_plan_reference_number of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if forward_plan_reference_number is None:
            raise ValueError("Invalid value for `forward_plan_reference_number`, must not be `None`")  # noqa: E501

        self._forward_plan_reference_number = forward_plan_reference_number

    @property
    def start_date(self):
        """Gets the start_date of this ForwardPlanResponse.  # noqa: E501


        :return: The start_date of this ForwardPlanResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this ForwardPlanResponse.


        :param start_date: The start_date of this ForwardPlanResponse.  # noqa: E501
        :type: datetime
        """
        if start_date is None:
            raise ValueError("Invalid value for `start_date`, must not be `None`")  # noqa: E501

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this ForwardPlanResponse.  # noqa: E501


        :return: The end_date of this ForwardPlanResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this ForwardPlanResponse.


        :param end_date: The end_date of this ForwardPlanResponse.  # noqa: E501
        :type: datetime
        """
        if end_date is None:
            raise ValueError("Invalid value for `end_date`, must not be `None`")  # noqa: E501

        self._end_date = end_date

    @property
    def forward_plan_status(self):
        """Gets the forward_plan_status of this ForwardPlanResponse.  # noqa: E501


        :return: The forward_plan_status of this ForwardPlanResponse.  # noqa: E501
        :rtype: ForwardPlanStatusResponse
        """
        return self._forward_plan_status

    @forward_plan_status.setter
    def forward_plan_status(self, forward_plan_status):
        """Sets the forward_plan_status of this ForwardPlanResponse.


        :param forward_plan_status: The forward_plan_status of this ForwardPlanResponse.  # noqa: E501
        :type: ForwardPlanStatusResponse
        """
        if forward_plan_status is None:
            raise ValueError("Invalid value for `forward_plan_status`, must not be `None`")  # noqa: E501

        self._forward_plan_status = forward_plan_status

    @property
    def forward_plan_status_string(self):
        """Gets the forward_plan_status_string of this ForwardPlanResponse.  # noqa: E501


        :return: The forward_plan_status_string of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._forward_plan_status_string

    @forward_plan_status_string.setter
    def forward_plan_status_string(self, forward_plan_status_string):
        """Sets the forward_plan_status_string of this ForwardPlanResponse.


        :param forward_plan_status_string: The forward_plan_status_string of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if forward_plan_status_string is None:
            raise ValueError("Invalid value for `forward_plan_status_string`, must not be `None`")  # noqa: E501

        self._forward_plan_status_string = forward_plan_status_string

    @property
    def promoter_organisation(self):
        """Gets the promoter_organisation of this ForwardPlanResponse.  # noqa: E501


        :return: The promoter_organisation of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._promoter_organisation

    @promoter_organisation.setter
    def promoter_organisation(self, promoter_organisation):
        """Sets the promoter_organisation of this ForwardPlanResponse.


        :param promoter_organisation: The promoter_organisation of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if promoter_organisation is None:
            raise ValueError("Invalid value for `promoter_organisation`, must not be `None`")  # noqa: E501

        self._promoter_organisation = promoter_organisation

    @property
    def promoter_swa_code(self):
        """Gets the promoter_swa_code of this ForwardPlanResponse.  # noqa: E501


        :return: The promoter_swa_code of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._promoter_swa_code

    @promoter_swa_code.setter
    def promoter_swa_code(self, promoter_swa_code):
        """Sets the promoter_swa_code of this ForwardPlanResponse.


        :param promoter_swa_code: The promoter_swa_code of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if promoter_swa_code is None:
            raise ValueError("Invalid value for `promoter_swa_code`, must not be `None`")  # noqa: E501

        self._promoter_swa_code = promoter_swa_code

    @property
    def promoter_contact_details(self):
        """Gets the promoter_contact_details of this ForwardPlanResponse.  # noqa: E501


        :return: The promoter_contact_details of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._promoter_contact_details

    @promoter_contact_details.setter
    def promoter_contact_details(self, promoter_contact_details):
        """Sets the promoter_contact_details of this ForwardPlanResponse.


        :param promoter_contact_details: The promoter_contact_details of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if promoter_contact_details is None:
            raise ValueError("Invalid value for `promoter_contact_details`, must not be `None`")  # noqa: E501

        self._promoter_contact_details = promoter_contact_details

    @property
    def highway_authority(self):
        """Gets the highway_authority of this ForwardPlanResponse.  # noqa: E501


        :return: The highway_authority of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._highway_authority

    @highway_authority.setter
    def highway_authority(self, highway_authority):
        """Sets the highway_authority of this ForwardPlanResponse.


        :param highway_authority: The highway_authority of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if highway_authority is None:
            raise ValueError("Invalid value for `highway_authority`, must not be `None`")  # noqa: E501

        self._highway_authority = highway_authority

    @property
    def highway_authority_swa_code(self):
        """Gets the highway_authority_swa_code of this ForwardPlanResponse.  # noqa: E501


        :return: The highway_authority_swa_code of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._highway_authority_swa_code

    @highway_authority_swa_code.setter
    def highway_authority_swa_code(self, highway_authority_swa_code):
        """Sets the highway_authority_swa_code of this ForwardPlanResponse.


        :param highway_authority_swa_code: The highway_authority_swa_code of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if highway_authority_swa_code is None:
            raise ValueError("Invalid value for `highway_authority_swa_code`, must not be `None`")  # noqa: E501

        self._highway_authority_swa_code = highway_authority_swa_code

    @property
    def workstream_prefix(self):
        """Gets the workstream_prefix of this ForwardPlanResponse.  # noqa: E501


        :return: The workstream_prefix of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._workstream_prefix

    @workstream_prefix.setter
    def workstream_prefix(self, workstream_prefix):
        """Sets the workstream_prefix of this ForwardPlanResponse.


        :param workstream_prefix: The workstream_prefix of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if workstream_prefix is None:
            raise ValueError("Invalid value for `workstream_prefix`, must not be `None`")  # noqa: E501

        self._workstream_prefix = workstream_prefix

    @property
    def works_coordinates(self):
        """Gets the works_coordinates of this ForwardPlanResponse.  # noqa: E501


        :return: The works_coordinates of this ForwardPlanResponse.  # noqa: E501
        :rtype: object
        """
        return self._works_coordinates

    @works_coordinates.setter
    def works_coordinates(self, works_coordinates):
        """Sets the works_coordinates of this ForwardPlanResponse.


        :param works_coordinates: The works_coordinates of this ForwardPlanResponse.  # noqa: E501
        :type: object
        """
        if works_coordinates is None:
            raise ValueError("Invalid value for `works_coordinates`, must not be `None`")  # noqa: E501

        self._works_coordinates = works_coordinates

    @property
    def street_name(self):
        """Gets the street_name of this ForwardPlanResponse.  # noqa: E501


        :return: The street_name of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._street_name

    @street_name.setter
    def street_name(self, street_name):
        """Sets the street_name of this ForwardPlanResponse.


        :param street_name: The street_name of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if street_name is None:
            raise ValueError("Invalid value for `street_name`, must not be `None`")  # noqa: E501

        self._street_name = street_name

    @property
    def town(self):
        """Gets the town of this ForwardPlanResponse.  # noqa: E501


        :return: The town of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._town

    @town.setter
    def town(self, town):
        """Sets the town of this ForwardPlanResponse.


        :param town: The town of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """

        self._town = town

    @property
    def area_name(self):
        """Gets the area_name of this ForwardPlanResponse.  # noqa: E501


        :return: The area_name of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._area_name

    @area_name.setter
    def area_name(self, area_name):
        """Sets the area_name of this ForwardPlanResponse.


        :param area_name: The area_name of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """

        self._area_name = area_name

    @property
    def usrn(self):
        """Gets the usrn of this ForwardPlanResponse.  # noqa: E501


        :return: The usrn of this ForwardPlanResponse.  # noqa: E501
        :rtype: float
        """
        return self._usrn

    @usrn.setter
    def usrn(self, usrn):
        """Sets the usrn of this ForwardPlanResponse.


        :param usrn: The usrn of this ForwardPlanResponse.  # noqa: E501
        :type: float
        """
        if usrn is None:
            raise ValueError("Invalid value for `usrn`, must not be `None`")  # noqa: E501

        self._usrn = usrn

    @property
    def road_category(self):
        """Gets the road_category of this ForwardPlanResponse.  # noqa: E501


        :return: The road_category of this ForwardPlanResponse.  # noqa: E501
        :rtype: float
        """
        return self._road_category

    @road_category.setter
    def road_category(self, road_category):
        """Sets the road_category of this ForwardPlanResponse.


        :param road_category: The road_category of this ForwardPlanResponse.  # noqa: E501
        :type: float
        """
        if road_category is None:
            raise ValueError("Invalid value for `road_category`, must not be `None`")  # noqa: E501

        self._road_category = road_category

    @property
    def date_created(self):
        """Gets the date_created of this ForwardPlanResponse.  # noqa: E501


        :return: The date_created of this ForwardPlanResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this ForwardPlanResponse.


        :param date_created: The date_created of this ForwardPlanResponse.  # noqa: E501
        :type: datetime
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def works_location_description(self):
        """Gets the works_location_description of this ForwardPlanResponse.  # noqa: E501


        :return: The works_location_description of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._works_location_description

    @works_location_description.setter
    def works_location_description(self, works_location_description):
        """Sets the works_location_description of this ForwardPlanResponse.


        :param works_location_description: The works_location_description of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if works_location_description is None:
            raise ValueError("Invalid value for `works_location_description`, must not be `None`")  # noqa: E501

        self._works_location_description = works_location_description

    @property
    def description_of_work(self):
        """Gets the description_of_work of this ForwardPlanResponse.  # noqa: E501


        :return: The description_of_work of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._description_of_work

    @description_of_work.setter
    def description_of_work(self, description_of_work):
        """Sets the description_of_work of this ForwardPlanResponse.


        :param description_of_work: The description_of_work of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """
        if description_of_work is None:
            raise ValueError("Invalid value for `description_of_work`, must not be `None`")  # noqa: E501

        self._description_of_work = description_of_work

    @property
    def project_reference_number(self):
        """Gets the project_reference_number of this ForwardPlanResponse.  # noqa: E501


        :return: The project_reference_number of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._project_reference_number

    @project_reference_number.setter
    def project_reference_number(self, project_reference_number):
        """Sets the project_reference_number of this ForwardPlanResponse.


        :param project_reference_number: The project_reference_number of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """

        self._project_reference_number = project_reference_number

    @property
    def traffic_management_type(self):
        """Gets the traffic_management_type of this ForwardPlanResponse.  # noqa: E501


        :return: The traffic_management_type of this ForwardPlanResponse.  # noqa: E501
        :rtype: AllOfForwardPlanResponseTrafficManagementType
        """
        return self._traffic_management_type

    @traffic_management_type.setter
    def traffic_management_type(self, traffic_management_type):
        """Sets the traffic_management_type of this ForwardPlanResponse.


        :param traffic_management_type: The traffic_management_type of this ForwardPlanResponse.  # noqa: E501
        :type: AllOfForwardPlanResponseTrafficManagementType
        """

        self._traffic_management_type = traffic_management_type

    @property
    def traffic_management_type_string(self):
        """Gets the traffic_management_type_string of this ForwardPlanResponse.  # noqa: E501


        :return: The traffic_management_type_string of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._traffic_management_type_string

    @traffic_management_type_string.setter
    def traffic_management_type_string(self, traffic_management_type_string):
        """Sets the traffic_management_type_string of this ForwardPlanResponse.


        :param traffic_management_type_string: The traffic_management_type_string of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """

        self._traffic_management_type_string = traffic_management_type_string

    @property
    def additional_info(self):
        """Gets the additional_info of this ForwardPlanResponse.  # noqa: E501


        :return: The additional_info of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._additional_info

    @additional_info.setter
    def additional_info(self, additional_info):
        """Sets the additional_info of this ForwardPlanResponse.


        :param additional_info: The additional_info of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """

        self._additional_info = additional_info

    @property
    def forward_plan_asds(self):
        """Gets the forward_plan_asds of this ForwardPlanResponse.  # noqa: E501


        :return: The forward_plan_asds of this ForwardPlanResponse.  # noqa: E501
        :rtype: list[PermitASDResponse]
        """
        return self._forward_plan_asds

    @forward_plan_asds.setter
    def forward_plan_asds(self, forward_plan_asds):
        """Sets the forward_plan_asds of this ForwardPlanResponse.


        :param forward_plan_asds: The forward_plan_asds of this ForwardPlanResponse.  # noqa: E501
        :type: list[PermitASDResponse]
        """

        self._forward_plan_asds = forward_plan_asds

    @property
    def cancelled_reason(self):
        """Gets the cancelled_reason of this ForwardPlanResponse.  # noqa: E501


        :return: The cancelled_reason of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._cancelled_reason

    @cancelled_reason.setter
    def cancelled_reason(self, cancelled_reason):
        """Sets the cancelled_reason of this ForwardPlanResponse.


        :param cancelled_reason: The cancelled_reason of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """

        self._cancelled_reason = cancelled_reason

    @property
    def hs2_in_act_limits(self):
        """Gets the hs2_in_act_limits of this ForwardPlanResponse.  # noqa: E501


        :return: The hs2_in_act_limits of this ForwardPlanResponse.  # noqa: E501
        :rtype: bool
        """
        return self._hs2_in_act_limits

    @hs2_in_act_limits.setter
    def hs2_in_act_limits(self, hs2_in_act_limits):
        """Sets the hs2_in_act_limits of this ForwardPlanResponse.


        :param hs2_in_act_limits: The hs2_in_act_limits of this ForwardPlanResponse.  # noqa: E501
        :type: bool
        """

        self._hs2_in_act_limits = hs2_in_act_limits

    @property
    def hs2_consultation_requested_response_date(self):
        """Gets the hs2_consultation_requested_response_date of this ForwardPlanResponse.  # noqa: E501


        :return: The hs2_consultation_requested_response_date of this ForwardPlanResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._hs2_consultation_requested_response_date

    @hs2_consultation_requested_response_date.setter
    def hs2_consultation_requested_response_date(self, hs2_consultation_requested_response_date):
        """Sets the hs2_consultation_requested_response_date of this ForwardPlanResponse.


        :param hs2_consultation_requested_response_date: The hs2_consultation_requested_response_date of this ForwardPlanResponse.  # noqa: E501
        :type: datetime
        """

        self._hs2_consultation_requested_response_date = hs2_consultation_requested_response_date

    @property
    def hs2_highway_exemption(self):
        """Gets the hs2_highway_exemption of this ForwardPlanResponse.  # noqa: E501


        :return: The hs2_highway_exemption of this ForwardPlanResponse.  # noqa: E501
        :rtype: AllOfForwardPlanResponseHs2HighwayExemption
        """
        return self._hs2_highway_exemption

    @hs2_highway_exemption.setter
    def hs2_highway_exemption(self, hs2_highway_exemption):
        """Sets the hs2_highway_exemption of this ForwardPlanResponse.


        :param hs2_highway_exemption: The hs2_highway_exemption of this ForwardPlanResponse.  # noqa: E501
        :type: AllOfForwardPlanResponseHs2HighwayExemption
        """

        self._hs2_highway_exemption = hs2_highway_exemption

    @property
    def hs2_highway_exemption_string(self):
        """Gets the hs2_highway_exemption_string of this ForwardPlanResponse.  # noqa: E501


        :return: The hs2_highway_exemption_string of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._hs2_highway_exemption_string

    @hs2_highway_exemption_string.setter
    def hs2_highway_exemption_string(self, hs2_highway_exemption_string):
        """Sets the hs2_highway_exemption_string of this ForwardPlanResponse.


        :param hs2_highway_exemption_string: The hs2_highway_exemption_string of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """

        self._hs2_highway_exemption_string = hs2_highway_exemption_string

    @property
    def hs2_works_type(self):
        """Gets the hs2_works_type of this ForwardPlanResponse.  # noqa: E501


        :return: The hs2_works_type of this ForwardPlanResponse.  # noqa: E501
        :rtype: AllOfForwardPlanResponseHs2WorksType
        """
        return self._hs2_works_type

    @hs2_works_type.setter
    def hs2_works_type(self, hs2_works_type):
        """Sets the hs2_works_type of this ForwardPlanResponse.


        :param hs2_works_type: The hs2_works_type of this ForwardPlanResponse.  # noqa: E501
        :type: AllOfForwardPlanResponseHs2WorksType
        """

        self._hs2_works_type = hs2_works_type

    @property
    def hs2_works_type_string(self):
        """Gets the hs2_works_type_string of this ForwardPlanResponse.  # noqa: E501


        :return: The hs2_works_type_string of this ForwardPlanResponse.  # noqa: E501
        :rtype: str
        """
        return self._hs2_works_type_string

    @hs2_works_type_string.setter
    def hs2_works_type_string(self, hs2_works_type_string):
        """Sets the hs2_works_type_string of this ForwardPlanResponse.


        :param hs2_works_type_string: The hs2_works_type_string of this ForwardPlanResponse.  # noqa: E501
        :type: str
        """

        self._hs2_works_type_string = hs2_works_type_string

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ForwardPlanResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ForwardPlanResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager GeoJSON API

    See API specification Resource Guide > GeoJSON API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.default_api import DefaultApi  # noqa: E501
from swagger_client.rest import ApiException


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_activities_intersecting_bounds(self):
        """Test case for get_activities_intersecting_bounds

        """
        pass

    def test_get_ancillary_information_intersect_bounding_box(self):
        """Test case for get_ancillary_information_intersect_bounding_box

        """
        pass

    def test_get_forward_plans_intersect_bounding_box(self):
        """Test case for get_forward_plans_intersect_bounding_box

        """
        pass

    def test_get_hs2_act_limits_intersecting_bounds(self):
        """Test case for get_hs2_act_limits_intersecting_bounds

        """
        pass

    def test_get_material_classifications_intersect_bounding_box(self):
        """Test case for get_material_classifications_intersect_bounding_box

        """
        pass

    def test_get_section58s_intersect_bounding_box(self):
        """Test case for get_section58s_intersect_bounding_box

        """
        pass

    def test_get_works_intersect_bounding_box(self):
        """Test case for get_works_intersect_bounding_box

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Street Manager Street Lookup API

    See API specification Resource Guide > Street Lookup API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.default_api import DefaultApi  # noqa: E501
from swagger_client.rest import ApiException


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_streets(self):
        """Test case for get_streets

        """
        pass

    def test_get_streets_by_query(self):
        """Test case for get_streets_by_query

        """
        pass

    def test_get_streets_by_usrn(self):
        """Test case for get_streets_by_usrn

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FPNSummaryResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'fpn_reference_number': 'str',
        'fpn_offence_type': 'OffenceCodeResponse',
        'fpn_offence_type_string': 'str',
        'issue_date_time': 'datetime',
        'fpn_status': 'FPNStatusResponse',
        'fpn_status_string': 'str',
        'status_changed_date': 'datetime'
    }

    attribute_map = {
        'fpn_reference_number': 'fpn_reference_number',
        'fpn_offence_type': 'fpn_offence_type',
        'fpn_offence_type_string': 'fpn_offence_type_string',
        'issue_date_time': 'issue_date_time',
        'fpn_status': 'fpn_status',
        'fpn_status_string': 'fpn_status_string',
        'status_changed_date': 'status_changed_date'
    }

    def __init__(self, fpn_reference_number=None, fpn_offence_type=None, fpn_offence_type_string=None, issue_date_time=None, fpn_status=None, fpn_status_string=None, status_changed_date=None):  # noqa: E501
        """FPNSummaryResponse - a model defined in Swagger"""  # noqa: E501
        self._fpn_reference_number = None
        self._fpn_offence_type = None
        self._fpn_offence_type_string = None
        self._issue_date_time = None
        self._fpn_status = None
        self._fpn_status_string = None
        self._status_changed_date = None
        self.discriminator = None
        self.fpn_reference_number = fpn_reference_number
        self.fpn_offence_type = fpn_offence_type
        self.fpn_offence_type_string = fpn_offence_type_string
        self.issue_date_time = issue_date_time
        self.fpn_status = fpn_status
        self.fpn_status_string = fpn_status_string
        self.status_changed_date = status_changed_date

    @property
    def fpn_reference_number(self):
        """Gets the fpn_reference_number of this FPNSummaryResponse.  # noqa: E501


        :return: The fpn_reference_number of this FPNSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._fpn_reference_number

    @fpn_reference_number.setter
    def fpn_reference_number(self, fpn_reference_number):
        """Sets the fpn_reference_number of this FPNSummaryResponse.


        :param fpn_reference_number: The fpn_reference_number of this FPNSummaryResponse.  # noqa: E501
        :type: str
        """
        if fpn_reference_number is None:
            raise ValueError("Invalid value for `fpn_reference_number`, must not be `None`")  # noqa: E501

        self._fpn_reference_number = fpn_reference_number

    @property
    def fpn_offence_type(self):
        """Gets the fpn_offence_type of this FPNSummaryResponse.  # noqa: E501


        :return: The fpn_offence_type of this FPNSummaryResponse.  # noqa: E501
        :rtype: OffenceCodeResponse
        """
        return self._fpn_offence_type

    @fpn_offence_type.setter
    def fpn_offence_type(self, fpn_offence_type):
        """Sets the fpn_offence_type of this FPNSummaryResponse.


        :param fpn_offence_type: The fpn_offence_type of this FPNSummaryResponse.  # noqa: E501
        :type: OffenceCodeResponse
        """
        if fpn_offence_type is None:
            raise ValueError("Invalid value for `fpn_offence_type`, must not be `None`")  # noqa: E501

        self._fpn_offence_type = fpn_offence_type

    @property
    def fpn_offence_type_string(self):
        """Gets the fpn_offence_type_string of this FPNSummaryResponse.  # noqa: E501


        :return: The fpn_offence_type_string of this FPNSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._fpn_offence_type_string

    @fpn_offence_type_string.setter
    def fpn_offence_type_string(self, fpn_offence_type_string):
        """Sets the fpn_offence_type_string of this FPNSummaryResponse.


        :param fpn_offence_type_string: The fpn_offence_type_string of this FPNSummaryResponse.  # noqa: E501
        :type: str
        """
        if fpn_offence_type_string is None:
            raise ValueError("Invalid value for `fpn_offence_type_string`, must not be `None`")  # noqa: E501

        self._fpn_offence_type_string = fpn_offence_type_string

    @property
    def issue_date_time(self):
        """Gets the issue_date_time of this FPNSummaryResponse.  # noqa: E501


        :return: The issue_date_time of this FPNSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._issue_date_time

    @issue_date_time.setter
    def issue_date_time(self, issue_date_time):
        """Sets the issue_date_time of this FPNSummaryResponse.


        :param issue_date_time: The issue_date_time of this FPNSummaryResponse.  # noqa: E501
        :type: datetime
        """
        if issue_date_time is None:
            raise ValueError("Invalid value for `issue_date_time`, must not be `None`")  # noqa: E501

        self._issue_date_time = issue_date_time

    @property
    def fpn_status(self):
        """Gets the fpn_status of this FPNSummaryResponse.  # noqa: E501


        :return: The fpn_status of this FPNSummaryResponse.  # noqa: E501
        :rtype: FPNStatusResponse
        """
        return self._fpn_status

    @fpn_status.setter
    def fpn_status(self, fpn_status):
        """Sets the fpn_status of this FPNSummaryResponse.


        :param fpn_status: The fpn_status of this FPNSummaryResponse.  # noqa: E501
        :type: FPNStatusResponse
        """
        if fpn_status is None:
            raise ValueError("Invalid value for `fpn_status`, must not be `None`")  # noqa: E501

        self._fpn_status = fpn_status

    @property
    def fpn_status_string(self):
        """Gets the fpn_status_string of this FPNSummaryResponse.  # noqa: E501


        :return: The fpn_status_string of this FPNSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._fpn_status_string

    @fpn_status_string.setter
    def fpn_status_string(self, fpn_status_string):
        """Sets the fpn_status_string of this FPNSummaryResponse.


        :param fpn_status_string: The fpn_status_string of this FPNSummaryResponse.  # noqa: E501
        :type: str
        """
        if fpn_status_string is None:
            raise ValueError("Invalid value for `fpn_status_string`, must not be `None`")  # noqa: E501

        self._fpn_status_string = fpn_status_string

    @property
    def status_changed_date(self):
        """Gets the status_changed_date of this FPNSummaryResponse.  # noqa: E501


        :return: The status_changed_date of this FPNSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._status_changed_date

    @status_changed_date.setter
    def status_changed_date(self, status_changed_date):
        """Sets the status_changed_date of this FPNSummaryResponse.


        :param status_changed_date: The status_changed_date of this FPNSummaryResponse.  # noqa: E501
        :type: datetime
        """
        if status_changed_date is None:
            raise ValueError("Invalid value for `status_changed_date`, must not be `None`")  # noqa: E501

        self._status_changed_date = status_changed_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FPNSummaryResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FPNSummaryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""
Street Manager - A tool for managing street data
"""

__version__ = "0.1.0"

# Import main modules to make them available at the package level
from . import work
from . import geojson
from . import lookup 


# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WorkResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'work_reference_number': 'str',
        'workstream_prefix': 'str',
        'promoter_swa_code': 'str',
        'promoter_organisation': 'str',
        'promoter_organisation_industry_type': 'AllOfWorkResponsePromoterOrganisationIndustryType',
        'promoter_organisation_industry_type_string': 'str',
        'highway_authority_swa_code': 'str',
        'highway_authority': 'str',
        'street_name': 'str',
        'town': 'str',
        'area_name': 'str',
        'road_category': 'float',
        'works_coordinates': 'object',
        'usrn': 'float',
        'inspection_units': 'float',
        'work_status': 'WorkStatusResponse',
        'work_status_string': 'str',
        'works_location_description': 'str',
        'work_start_date': 'datetime',
        'work_end_date': 'datetime',
        'work_start_time': 'datetime',
        'work_end_time': 'datetime',
        'description_of_work': 'str',
        'active_permit': 'AllOfWorkResponseActivePermit',
        'forward_plan': 'AllOfWorkResponseForwardPlan',
        'permits': 'list[PermitSummaryResponse]',
        'history': 'list[WorkHistorySummaryResponse]',
        'sites': 'list[SiteSummaryResponse]',
        'inspections': 'list[InspectionSummaryResponse]',
        'fpns': 'list[FPNSummaryResponse]',
        'section_81': 'AllOfWorkResponseSection81',
        'files': 'list[FileResponse]',
        'pbi_sample_inspections': 'list[PbiSampleInspectionSummaryResponse]',
        'number_of_sites': 'float',
        'section74s': 'list[Section74SummaryResponse]',
        'street_line': 'object',
        'private_street_notice': 'AllOfWorkResponsePrivateStreetNotice',
        'non_compliances': 'list[NonComplianceSummaryResponse]',
        'latest_comments': 'list[CommentResponse]'
    }

    attribute_map = {
        'work_reference_number': 'work_reference_number',
        'workstream_prefix': 'workstream_prefix',
        'promoter_swa_code': 'promoter_swa_code',
        'promoter_organisation': 'promoter_organisation',
        'promoter_organisation_industry_type': 'promoter_organisation_industry_type',
        'promoter_organisation_industry_type_string': 'promoter_organisation_industry_type_string',
        'highway_authority_swa_code': 'highway_authority_swa_code',
        'highway_authority': 'highway_authority',
        'street_name': 'street_name',
        'town': 'town',
        'area_name': 'area_name',
        'road_category': 'road_category',
        'works_coordinates': 'works_coordinates',
        'usrn': 'usrn',
        'inspection_units': 'inspection_units',
        'work_status': 'work_status',
        'work_status_string': 'work_status_string',
        'works_location_description': 'works_location_description',
        'work_start_date': 'work_start_date',
        'work_end_date': 'work_end_date',
        'work_start_time': 'work_start_time',
        'work_end_time': 'work_end_time',
        'description_of_work': 'description_of_work',
        'active_permit': 'active_permit',
        'forward_plan': 'forward_plan',
        'permits': 'permits',
        'history': 'history',
        'sites': 'sites',
        'inspections': 'inspections',
        'fpns': 'fpns',
        'section_81': 'section_81',
        'files': 'files',
        'pbi_sample_inspections': 'pbi_sample_inspections',
        'number_of_sites': 'number_of_sites',
        'section74s': 'section74s',
        'street_line': 'street_line',
        'private_street_notice': 'private_street_notice',
        'non_compliances': 'non_compliances',
        'latest_comments': 'latest_comments'
    }

    def __init__(self, work_reference_number=None, workstream_prefix=None, promoter_swa_code=None, promoter_organisation=None, promoter_organisation_industry_type=None, promoter_organisation_industry_type_string=None, highway_authority_swa_code=None, highway_authority=None, street_name=None, town=None, area_name=None, road_category=None, works_coordinates=None, usrn=None, inspection_units=None, work_status=None, work_status_string=None, works_location_description=None, work_start_date=None, work_end_date=None, work_start_time=None, work_end_time=None, description_of_work=None, active_permit=None, forward_plan=None, permits=None, history=None, sites=None, inspections=None, fpns=None, section_81=None, files=None, pbi_sample_inspections=None, number_of_sites=None, section74s=None, street_line=None, private_street_notice=None, non_compliances=None, latest_comments=None):  # noqa: E501
        """WorkResponse - a model defined in Swagger"""  # noqa: E501
        self._work_reference_number = None
        self._workstream_prefix = None
        self._promoter_swa_code = None
        self._promoter_organisation = None
        self._promoter_organisation_industry_type = None
        self._promoter_organisation_industry_type_string = None
        self._highway_authority_swa_code = None
        self._highway_authority = None
        self._street_name = None
        self._town = None
        self._area_name = None
        self._road_category = None
        self._works_coordinates = None
        self._usrn = None
        self._inspection_units = None
        self._work_status = None
        self._work_status_string = None
        self._works_location_description = None
        self._work_start_date = None
        self._work_end_date = None
        self._work_start_time = None
        self._work_end_time = None
        self._description_of_work = None
        self._active_permit = None
        self._forward_plan = None
        self._permits = None
        self._history = None
        self._sites = None
        self._inspections = None
        self._fpns = None
        self._section_81 = None
        self._files = None
        self._pbi_sample_inspections = None
        self._number_of_sites = None
        self._section74s = None
        self._street_line = None
        self._private_street_notice = None
        self._non_compliances = None
        self._latest_comments = None
        self.discriminator = None
        self.work_reference_number = work_reference_number
        self.workstream_prefix = workstream_prefix
        self.promoter_swa_code = promoter_swa_code
        self.promoter_organisation = promoter_organisation
        if promoter_organisation_industry_type is not None:
            self.promoter_organisation_industry_type = promoter_organisation_industry_type
        if promoter_organisation_industry_type_string is not None:
            self.promoter_organisation_industry_type_string = promoter_organisation_industry_type_string
        self.highway_authority_swa_code = highway_authority_swa_code
        self.highway_authority = highway_authority
        self.street_name = street_name
        if town is not None:
            self.town = town
        if area_name is not None:
            self.area_name = area_name
        self.road_category = road_category
        self.works_coordinates = works_coordinates
        self.usrn = usrn
        if inspection_units is not None:
            self.inspection_units = inspection_units
        self.work_status = work_status
        self.work_status_string = work_status_string
        self.works_location_description = works_location_description
        if work_start_date is not None:
            self.work_start_date = work_start_date
        if work_end_date is not None:
            self.work_end_date = work_end_date
        if work_start_time is not None:
            self.work_start_time = work_start_time
        if work_end_time is not None:
            self.work_end_time = work_end_time
        if description_of_work is not None:
            self.description_of_work = description_of_work
        if active_permit is not None:
            self.active_permit = active_permit
        if forward_plan is not None:
            self.forward_plan = forward_plan
        if permits is not None:
            self.permits = permits
        self.history = history
        if sites is not None:
            self.sites = sites
        if inspections is not None:
            self.inspections = inspections
        if fpns is not None:
            self.fpns = fpns
        if section_81 is not None:
            self.section_81 = section_81
        if files is not None:
            self.files = files
        if pbi_sample_inspections is not None:
            self.pbi_sample_inspections = pbi_sample_inspections
        if number_of_sites is not None:
            self.number_of_sites = number_of_sites
        if section74s is not None:
            self.section74s = section74s
        if street_line is not None:
            self.street_line = street_line
        if private_street_notice is not None:
            self.private_street_notice = private_street_notice
        if non_compliances is not None:
            self.non_compliances = non_compliances
        if latest_comments is not None:
            self.latest_comments = latest_comments

    @property
    def work_reference_number(self):
        """Gets the work_reference_number of this WorkResponse.  # noqa: E501


        :return: The work_reference_number of this WorkResponse.  # noqa: E501
        :rtype: str
        """
        return self._work_reference_number

    @work_reference_number.setter
    def work_reference_number(self, work_reference_number):
        """Sets the work_reference_number of this WorkResponse.


        :param work_reference_number: The work_reference_number of this WorkResponse.  # noqa: E501
        :type: str
        """
        if work_reference_number is None:
            raise ValueError("Invalid value for `work_reference_number`, must not be `None`")  # noqa: E501

        self._work_reference_number = work_reference_number

    @property
    def workstream_prefix(self):
        """Gets the workstream_prefix of this WorkResponse.  # noqa: E501


        :return: The workstream_prefix of this WorkResponse.  # noqa: E501
        :rtype: str
        """
        return self._workstream_prefix

    @workstream_prefix.setter
    def workstream_prefix(self, workstream_prefix):
        """Sets the workstream_prefix of this WorkResponse.


        :param workstream_prefix: The workstream_prefix of this WorkResponse.  # noqa: E501
        :type: str
        """
        if workstream_prefix is None:
            raise ValueError("Invalid value for `workstream_prefix`, must not be `None`")  # noqa: E501

        self._workstream_prefix = workstream_prefix

    @property
    def promoter_swa_code(self):
        """Gets the promoter_swa_code of this WorkResponse.  # noqa: E501


        :return: The promoter_swa_code of this WorkResponse.  # noqa: E501
        :rtype: str
        """
        return self._promoter_swa_code

    @promoter_swa_code.setter
    def promoter_swa_code(self, promoter_swa_code):
        """Sets the promoter_swa_code of this WorkResponse.


        :param promoter_swa_code: The promoter_swa_code of this WorkResponse.  # noqa: E501
        :type: str
        """
        if promoter_swa_code is None:
            raise ValueError("Invalid value for `promoter_swa_code`, must not be `None`")  # noqa: E501

        self._promoter_swa_code = promoter_swa_code

    @property
    def promoter_organisation(self):
        """Gets the promoter_organisation of this WorkResponse.  # noqa: E501


        :return: The promoter_organisation of this WorkResponse.  # noqa: E501
        :rtype: str
        """
        return self._promoter_organisation

    @promoter_organisation.setter
    def promoter_organisation(self, promoter_organisation):
        """Sets the promoter_organisation of this WorkResponse.


        :param promoter_organisation: The promoter_organisation of this WorkResponse.  # noqa: E501
        :type: str
        """
        if promoter_organisation is None:
            raise ValueError("Invalid value for `promoter_organisation`, must not be `None`")  # noqa: E501

        self._promoter_organisation = promoter_organisation

    @property
    def promoter_organisation_industry_type(self):
        """Gets the promoter_organisation_industry_type of this WorkResponse.  # noqa: E501


        :return: The promoter_organisation_industry_type of this WorkResponse.  # noqa: E501
        :rtype: AllOfWorkResponsePromoterOrganisationIndustryType
        """
        return self._promoter_organisation_industry_type

    @promoter_organisation_industry_type.setter
    def promoter_organisation_industry_type(self, promoter_organisation_industry_type):
        """Sets the promoter_organisation_industry_type of this WorkResponse.


        :param promoter_organisation_industry_type: The promoter_organisation_industry_type of this WorkResponse.  # noqa: E501
        :type: AllOfWorkResponsePromoterOrganisationIndustryType
        """

        self._promoter_organisation_industry_type = promoter_organisation_industry_type

    @property
    def promoter_organisation_industry_type_string(self):
        """Gets the promoter_organisation_industry_type_string of this WorkResponse.  # noqa: E501


        :return: The promoter_organisation_industry_type_string of this WorkResponse.  # noqa: E501
        :rtype: str
        """
        return self._promoter_organisation_industry_type_string

    @promoter_organisation_industry_type_string.setter
    def promoter_organisation_industry_type_string(self, promoter_organisation_industry_type_string):
        """Sets the promoter_organisation_industry_type_string of this WorkResponse.


        :param promoter_organisation_industry_type_string: The promoter_organisation_industry_type_string of this WorkResponse.  # noqa: E501
        :type: str
        """

        self._promoter_organisation_industry_type_string = promoter_organisation_industry_type_string

    @property
    def highway_authority_swa_code(self):
        """Gets the highway_authority_swa_code of this WorkResponse.  # noqa: E501


        :return: The highway_authority_swa_code of this WorkResponse.  # noqa: E501
        :rtype: str
        """
        return self._highway_authority_swa_code

    @highway_authority_swa_code.setter
    def highway_authority_swa_code(self, highway_authority_swa_code):
        """Sets the highway_authority_swa_code of this WorkResponse.


        :param highway_authority_swa_code: The highway_authority_swa_code of this WorkResponse.  # noqa: E501
        :type: str
        """
        if highway_authority_swa_code is None:
            raise ValueError("Invalid value for `highway_authority_swa_code`, must not be `None`")  # noqa: E501

        self._highway_authority_swa_code = highway_authority_swa_code

    @property
    def highway_authority(self):
        """Gets the highway_authority of this WorkResponse.  # noqa: E501


        :return: The highway_authority of this WorkResponse.  # noqa: E501
        :rtype: str
        """
        return self._highway_authority

    @highway_authority.setter
    def highway_authority(self, highway_authority):
        """Sets the highway_authority of this WorkResponse.


        :param highway_authority: The highway_authority of this WorkResponse.  # noqa: E501
        :type: str
        """
        if highway_authority is None:
            raise ValueError("Invalid value for `highway_authority`, must not be `None`")  # noqa: E501

        self._highway_authority = highway_authority

    @property
    def street_name(self):
        """Gets the street_name of this WorkResponse.  # noqa: E501


        :return: The street_name of this WorkResponse.  # noqa: E501
        :rtype: str
        """
        return self._street_name

    @street_name.setter
    def street_name(self, street_name):
        """Sets the street_name of this WorkResponse.


        :param street_name: The street_name of this WorkResponse.  # noqa: E501
        :type: str
        """
        if street_name is None:
            raise ValueError("Invalid value for `street_name`, must not be `None`")  # noqa: E501

        self._street_name = street_name

    @property
    def town(self):
        """Gets the town of this WorkResponse.  # noqa: E501


        :return: The town of this WorkResponse.  # noqa: E501
        :rtype: str
        """
        return self._town

    @town.setter
    def town(self, town):
        """Sets the town of this WorkResponse.


        :param town: The town of this WorkResponse.  # noqa: E501
        :type: str
        """

        self._town = town

    @property
    def area_name(self):
        """Gets the area_name of this WorkResponse.  # noqa: E501


        :return: The area_name of this WorkResponse.  # noqa: E501
        :rtype: str
        """
        return self._area_name

    @area_name.setter
    def area_name(self, area_name):
        """Sets the area_name of this WorkResponse.


        :param area_name: The area_name of this WorkResponse.  # noqa: E501
        :type: str
        """

        self._area_name = area_name

    @property
    def road_category(self):
        """Gets the road_category of this WorkResponse.  # noqa: E501


        :return: The road_category of this WorkResponse.  # noqa: E501
        :rtype: float
        """
        return self._road_category

    @road_category.setter
    def road_category(self, road_category):
        """Sets the road_category of this WorkResponse.


        :param road_category: The road_category of this WorkResponse.  # noqa: E501
        :type: float
        """
        if road_category is None:
            raise ValueError("Invalid value for `road_category`, must not be `None`")  # noqa: E501

        self._road_category = road_category

    @property
    def works_coordinates(self):
        """Gets the works_coordinates of this WorkResponse.  # noqa: E501


        :return: The works_coordinates of this WorkResponse.  # noqa: E501
        :rtype: object
        """
        return self._works_coordinates

    @works_coordinates.setter
    def works_coordinates(self, works_coordinates):
        """Sets the works_coordinates of this WorkResponse.


        :param works_coordinates: The works_coordinates of this WorkResponse.  # noqa: E501
        :type: object
        """
        if works_coordinates is None:
            raise ValueError("Invalid value for `works_coordinates`, must not be `None`")  # noqa: E501

        self._works_coordinates = works_coordinates

    @property
    def usrn(self):
        """Gets the usrn of this WorkResponse.  # noqa: E501


        :return: The usrn of this WorkResponse.  # noqa: E501
        :rtype: float
        """
        return self._usrn

    @usrn.setter
    def usrn(self, usrn):
        """Sets the usrn of this WorkResponse.


        :param usrn: The usrn of this WorkResponse.  # noqa: E501
        :type: float
        """
        if usrn is None:
            raise ValueError("Invalid value for `usrn`, must not be `None`")  # noqa: E501

        self._usrn = usrn

    @property
    def inspection_units(self):
        """Gets the inspection_units of this WorkResponse.  # noqa: E501


        :return: The inspection_units of this WorkResponse.  # noqa: E501
        :rtype: float
        """
        return self._inspection_units

    @inspection_units.setter
    def inspection_units(self, inspection_units):
        """Sets the inspection_units of this WorkResponse.


        :param inspection_units: The inspection_units of this WorkResponse.  # noqa: E501
        :type: float
        """

        self._inspection_units = inspection_units

    @property
    def work_status(self):
        """Gets the work_status of this WorkResponse.  # noqa: E501


        :return: The work_status of this WorkResponse.  # noqa: E501
        :rtype: WorkStatusResponse
        """
        return self._work_status

    @work_status.setter
    def work_status(self, work_status):
        """Sets the work_status of this WorkResponse.


        :param work_status: The work_status of this WorkResponse.  # noqa: E501
        :type: WorkStatusResponse
        """
        if work_status is None:
            raise ValueError("Invalid value for `work_status`, must not be `None`")  # noqa: E501

        self._work_status = work_status

    @property
    def work_status_string(self):
        """Gets the work_status_string of this WorkResponse.  # noqa: E501


        :return: The work_status_string of this WorkResponse.  # noqa: E501
        :rtype: str
        """
        return self._work_status_string

    @work_status_string.setter
    def work_status_string(self, work_status_string):
        """Sets the work_status_string of this WorkResponse.


        :param work_status_string: The work_status_string of this WorkResponse.  # noqa: E501
        :type: str
        """
        if work_status_string is None:
            raise ValueError("Invalid value for `work_status_string`, must not be `None`")  # noqa: E501

        self._work_status_string = work_status_string

    @property
    def works_location_description(self):
        """Gets the works_location_description of this WorkResponse.  # noqa: E501


        :return: The works_location_description of this WorkResponse.  # noqa: E501
        :rtype: str
        """
        return self._works_location_description

    @works_location_description.setter
    def works_location_description(self, works_location_description):
        """Sets the works_location_description of this WorkResponse.


        :param works_location_description: The works_location_description of this WorkResponse.  # noqa: E501
        :type: str
        """
        if works_location_description is None:
            raise ValueError("Invalid value for `works_location_description`, must not be `None`")  # noqa: E501

        self._works_location_description = works_location_description

    @property
    def work_start_date(self):
        """Gets the work_start_date of this WorkResponse.  # noqa: E501


        :return: The work_start_date of this WorkResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._work_start_date

    @work_start_date.setter
    def work_start_date(self, work_start_date):
        """Sets the work_start_date of this WorkResponse.


        :param work_start_date: The work_start_date of this WorkResponse.  # noqa: E501
        :type: datetime
        """

        self._work_start_date = work_start_date

    @property
    def work_end_date(self):
        """Gets the work_end_date of this WorkResponse.  # noqa: E501


        :return: The work_end_date of this WorkResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._work_end_date

    @work_end_date.setter
    def work_end_date(self, work_end_date):
        """Sets the work_end_date of this WorkResponse.


        :param work_end_date: The work_end_date of this WorkResponse.  # noqa: E501
        :type: datetime
        """

        self._work_end_date = work_end_date

    @property
    def work_start_time(self):
        """Gets the work_start_time of this WorkResponse.  # noqa: E501


        :return: The work_start_time of this WorkResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._work_start_time

    @work_start_time.setter
    def work_start_time(self, work_start_time):
        """Sets the work_start_time of this WorkResponse.


        :param work_start_time: The work_start_time of this WorkResponse.  # noqa: E501
        :type: datetime
        """

        self._work_start_time = work_start_time

    @property
    def work_end_time(self):
        """Gets the work_end_time of this WorkResponse.  # noqa: E501


        :return: The work_end_time of this WorkResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._work_end_time

    @work_end_time.setter
    def work_end_time(self, work_end_time):
        """Sets the work_end_time of this WorkResponse.


        :param work_end_time: The work_end_time of this WorkResponse.  # noqa: E501
        :type: datetime
        """

        self._work_end_time = work_end_time

    @property
    def description_of_work(self):
        """Gets the description_of_work of this WorkResponse.  # noqa: E501


        :return: The description_of_work of this WorkResponse.  # noqa: E501
        :rtype: str
        """
        return self._description_of_work

    @description_of_work.setter
    def description_of_work(self, description_of_work):
        """Sets the description_of_work of this WorkResponse.


        :param description_of_work: The description_of_work of this WorkResponse.  # noqa: E501
        :type: str
        """

        self._description_of_work = description_of_work

    @property
    def active_permit(self):
        """Gets the active_permit of this WorkResponse.  # noqa: E501


        :return: The active_permit of this WorkResponse.  # noqa: E501
        :rtype: AllOfWorkResponseActivePermit
        """
        return self._active_permit

    @active_permit.setter
    def active_permit(self, active_permit):
        """Sets the active_permit of this WorkResponse.


        :param active_permit: The active_permit of this WorkResponse.  # noqa: E501
        :type: AllOfWorkResponseActivePermit
        """

        self._active_permit = active_permit

    @property
    def forward_plan(self):
        """Gets the forward_plan of this WorkResponse.  # noqa: E501


        :return: The forward_plan of this WorkResponse.  # noqa: E501
        :rtype: AllOfWorkResponseForwardPlan
        """
        return self._forward_plan

    @forward_plan.setter
    def forward_plan(self, forward_plan):
        """Sets the forward_plan of this WorkResponse.


        :param forward_plan: The forward_plan of this WorkResponse.  # noqa: E501
        :type: AllOfWorkResponseForwardPlan
        """

        self._forward_plan = forward_plan

    @property
    def permits(self):
        """Gets the permits of this WorkResponse.  # noqa: E501


        :return: The permits of this WorkResponse.  # noqa: E501
        :rtype: list[PermitSummaryResponse]
        """
        return self._permits

    @permits.setter
    def permits(self, permits):
        """Sets the permits of this WorkResponse.


        :param permits: The permits of this WorkResponse.  # noqa: E501
        :type: list[PermitSummaryResponse]
        """

        self._permits = permits

    @property
    def history(self):
        """Gets the history of this WorkResponse.  # noqa: E501


        :return: The history of this WorkResponse.  # noqa: E501
        :rtype: list[WorkHistorySummaryResponse]
        """
        return self._history

    @history.setter
    def history(self, history):
        """Sets the history of this WorkResponse.


        :param history: The history of this WorkResponse.  # noqa: E501
        :type: list[WorkHistorySummaryResponse]
        """
        if history is None:
            raise ValueError("Invalid value for `history`, must not be `None`")  # noqa: E501

        self._history = history

    @property
    def sites(self):
        """Gets the sites of this WorkResponse.  # noqa: E501


        :return: The sites of this WorkResponse.  # noqa: E501
        :rtype: list[SiteSummaryResponse]
        """
        return self._sites

    @sites.setter
    def sites(self, sites):
        """Sets the sites of this WorkResponse.


        :param sites: The sites of this WorkResponse.  # noqa: E501
        :type: list[SiteSummaryResponse]
        """

        self._sites = sites

    @property
    def inspections(self):
        """Gets the inspections of this WorkResponse.  # noqa: E501


        :return: The inspections of this WorkResponse.  # noqa: E501
        :rtype: list[InspectionSummaryResponse]
        """
        return self._inspections

    @inspections.setter
    def inspections(self, inspections):
        """Sets the inspections of this WorkResponse.


        :param inspections: The inspections of this WorkResponse.  # noqa: E501
        :type: list[InspectionSummaryResponse]
        """

        self._inspections = inspections

    @property
    def fpns(self):
        """Gets the fpns of this WorkResponse.  # noqa: E501


        :return: The fpns of this WorkResponse.  # noqa: E501
        :rtype: list[FPNSummaryResponse]
        """
        return self._fpns

    @fpns.setter
    def fpns(self, fpns):
        """Sets the fpns of this WorkResponse.


        :param fpns: The fpns of this WorkResponse.  # noqa: E501
        :type: list[FPNSummaryResponse]
        """

        self._fpns = fpns

    @property
    def section_81(self):
        """Gets the section_81 of this WorkResponse.  # noqa: E501


        :return: The section_81 of this WorkResponse.  # noqa: E501
        :rtype: AllOfWorkResponseSection81
        """
        return self._section_81

    @section_81.setter
    def section_81(self, section_81):
        """Sets the section_81 of this WorkResponse.


        :param section_81: The section_81 of this WorkResponse.  # noqa: E501
        :type: AllOfWorkResponseSection81
        """

        self._section_81 = section_81

    @property
    def files(self):
        """Gets the files of this WorkResponse.  # noqa: E501


        :return: The files of this WorkResponse.  # noqa: E501
        :rtype: list[FileResponse]
        """
        return self._files

    @files.setter
    def files(self, files):
        """Sets the files of this WorkResponse.


        :param files: The files of this WorkResponse.  # noqa: E501
        :type: list[FileResponse]
        """

        self._files = files

    @property
    def pbi_sample_inspections(self):
        """Gets the pbi_sample_inspections of this WorkResponse.  # noqa: E501


        :return: The pbi_sample_inspections of this WorkResponse.  # noqa: E501
        :rtype: list[PbiSampleInspectionSummaryResponse]
        """
        return self._pbi_sample_inspections

    @pbi_sample_inspections.setter
    def pbi_sample_inspections(self, pbi_sample_inspections):
        """Sets the pbi_sample_inspections of this WorkResponse.


        :param pbi_sample_inspections: The pbi_sample_inspections of this WorkResponse.  # noqa: E501
        :type: list[PbiSampleInspectionSummaryResponse]
        """

        self._pbi_sample_inspections = pbi_sample_inspections

    @property
    def number_of_sites(self):
        """Gets the number_of_sites of this WorkResponse.  # noqa: E501


        :return: The number_of_sites of this WorkResponse.  # noqa: E501
        :rtype: float
        """
        return self._number_of_sites

    @number_of_sites.setter
    def number_of_sites(self, number_of_sites):
        """Sets the number_of_sites of this WorkResponse.


        :param number_of_sites: The number_of_sites of this WorkResponse.  # noqa: E501
        :type: float
        """

        self._number_of_sites = number_of_sites

    @property
    def section74s(self):
        """Gets the section74s of this WorkResponse.  # noqa: E501


        :return: The section74s of this WorkResponse.  # noqa: E501
        :rtype: list[Section74SummaryResponse]
        """
        return self._section74s

    @section74s.setter
    def section74s(self, section74s):
        """Sets the section74s of this WorkResponse.


        :param section74s: The section74s of this WorkResponse.  # noqa: E501
        :type: list[Section74SummaryResponse]
        """

        self._section74s = section74s

    @property
    def street_line(self):
        """Gets the street_line of this WorkResponse.  # noqa: E501


        :return: The street_line of this WorkResponse.  # noqa: E501
        :rtype: object
        """
        return self._street_line

    @street_line.setter
    def street_line(self, street_line):
        """Sets the street_line of this WorkResponse.


        :param street_line: The street_line of this WorkResponse.  # noqa: E501
        :type: object
        """

        self._street_line = street_line

    @property
    def private_street_notice(self):
        """Gets the private_street_notice of this WorkResponse.  # noqa: E501


        :return: The private_street_notice of this WorkResponse.  # noqa: E501
        :rtype: AllOfWorkResponsePrivateStreetNotice
        """
        return self._private_street_notice

    @private_street_notice.setter
    def private_street_notice(self, private_street_notice):
        """Sets the private_street_notice of this WorkResponse.


        :param private_street_notice: The private_street_notice of this WorkResponse.  # noqa: E501
        :type: AllOfWorkResponsePrivateStreetNotice
        """

        self._private_street_notice = private_street_notice

    @property
    def non_compliances(self):
        """Gets the non_compliances of this WorkResponse.  # noqa: E501


        :return: The non_compliances of this WorkResponse.  # noqa: E501
        :rtype: list[NonComplianceSummaryResponse]
        """
        return self._non_compliances

    @non_compliances.setter
    def non_compliances(self, non_compliances):
        """Sets the non_compliances of this WorkResponse.


        :param non_compliances: The non_compliances of this WorkResponse.  # noqa: E501
        :type: list[NonComplianceSummaryResponse]
        """

        self._non_compliances = non_compliances

    @property
    def latest_comments(self):
        """Gets the latest_comments of this WorkResponse.  # noqa: E501


        :return: The latest_comments of this WorkResponse.  # noqa: E501
        :rtype: list[CommentResponse]
        """
        return self._latest_comments

    @latest_comments.setter
    def latest_comments(self, latest_comments):
        """Sets the latest_comments of this WorkResponse.


        :param latest_comments: The latest_comments of this WorkResponse.  # noqa: E501
        :type: list[CommentResponse]
        """

        self._latest_comments = latest_comments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager GeoJSON API

    See API specification Resource Guide > GeoJSON API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ActivityProperties(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'activity_centre_point': 'GeoJSONCentrePoint',
        'activity_name': 'str',
        'activity_location_description': 'str',
        'activity_reference_number': 'str',
        'activity_type': 'ActivityActivityTypeResponse',
        'activity_type_string': 'str',
        'area_name': 'str',
        'cancelled': 'bool',
        'end_date': 'datetime',
        'street_name': 'str',
        'start_date': 'datetime'
    }

    attribute_map = {
        'activity_centre_point': 'activity_centre_point',
        'activity_name': 'activity_name',
        'activity_location_description': 'activity_location_description',
        'activity_reference_number': 'activity_reference_number',
        'activity_type': 'activity_type',
        'activity_type_string': 'activity_type_string',
        'area_name': 'area_name',
        'cancelled': 'cancelled',
        'end_date': 'end_date',
        'street_name': 'street_name',
        'start_date': 'start_date'
    }

    def __init__(self, activity_centre_point=None, activity_name=None, activity_location_description=None, activity_reference_number=None, activity_type=None, activity_type_string=None, area_name=None, cancelled=None, end_date=None, street_name=None, start_date=None):  # noqa: E501
        """ActivityProperties - a model defined in Swagger"""  # noqa: E501
        self._activity_centre_point = None
        self._activity_name = None
        self._activity_location_description = None
        self._activity_reference_number = None
        self._activity_type = None
        self._activity_type_string = None
        self._area_name = None
        self._cancelled = None
        self._end_date = None
        self._street_name = None
        self._start_date = None
        self.discriminator = None
        self.activity_centre_point = activity_centre_point
        self.activity_name = activity_name
        self.activity_location_description = activity_location_description
        self.activity_reference_number = activity_reference_number
        self.activity_type = activity_type
        self.activity_type_string = activity_type_string
        self.area_name = area_name
        self.cancelled = cancelled
        self.end_date = end_date
        self.street_name = street_name
        self.start_date = start_date

    @property
    def activity_centre_point(self):
        """Gets the activity_centre_point of this ActivityProperties.  # noqa: E501


        :return: The activity_centre_point of this ActivityProperties.  # noqa: E501
        :rtype: GeoJSONCentrePoint
        """
        return self._activity_centre_point

    @activity_centre_point.setter
    def activity_centre_point(self, activity_centre_point):
        """Sets the activity_centre_point of this ActivityProperties.


        :param activity_centre_point: The activity_centre_point of this ActivityProperties.  # noqa: E501
        :type: GeoJSONCentrePoint
        """
        if activity_centre_point is None:
            raise ValueError("Invalid value for `activity_centre_point`, must not be `None`")  # noqa: E501

        self._activity_centre_point = activity_centre_point

    @property
    def activity_name(self):
        """Gets the activity_name of this ActivityProperties.  # noqa: E501


        :return: The activity_name of this ActivityProperties.  # noqa: E501
        :rtype: str
        """
        return self._activity_name

    @activity_name.setter
    def activity_name(self, activity_name):
        """Sets the activity_name of this ActivityProperties.


        :param activity_name: The activity_name of this ActivityProperties.  # noqa: E501
        :type: str
        """
        if activity_name is None:
            raise ValueError("Invalid value for `activity_name`, must not be `None`")  # noqa: E501

        self._activity_name = activity_name

    @property
    def activity_location_description(self):
        """Gets the activity_location_description of this ActivityProperties.  # noqa: E501


        :return: The activity_location_description of this ActivityProperties.  # noqa: E501
        :rtype: str
        """
        return self._activity_location_description

    @activity_location_description.setter
    def activity_location_description(self, activity_location_description):
        """Sets the activity_location_description of this ActivityProperties.


        :param activity_location_description: The activity_location_description of this ActivityProperties.  # noqa: E501
        :type: str
        """
        if activity_location_description is None:
            raise ValueError("Invalid value for `activity_location_description`, must not be `None`")  # noqa: E501

        self._activity_location_description = activity_location_description

    @property
    def activity_reference_number(self):
        """Gets the activity_reference_number of this ActivityProperties.  # noqa: E501


        :return: The activity_reference_number of this ActivityProperties.  # noqa: E501
        :rtype: str
        """
        return self._activity_reference_number

    @activity_reference_number.setter
    def activity_reference_number(self, activity_reference_number):
        """Sets the activity_reference_number of this ActivityProperties.


        :param activity_reference_number: The activity_reference_number of this ActivityProperties.  # noqa: E501
        :type: str
        """
        if activity_reference_number is None:
            raise ValueError("Invalid value for `activity_reference_number`, must not be `None`")  # noqa: E501

        self._activity_reference_number = activity_reference_number

    @property
    def activity_type(self):
        """Gets the activity_type of this ActivityProperties.  # noqa: E501


        :return: The activity_type of this ActivityProperties.  # noqa: E501
        :rtype: ActivityActivityTypeResponse
        """
        return self._activity_type

    @activity_type.setter
    def activity_type(self, activity_type):
        """Sets the activity_type of this ActivityProperties.


        :param activity_type: The activity_type of this ActivityProperties.  # noqa: E501
        :type: ActivityActivityTypeResponse
        """
        if activity_type is None:
            raise ValueError("Invalid value for `activity_type`, must not be `None`")  # noqa: E501

        self._activity_type = activity_type

    @property
    def activity_type_string(self):
        """Gets the activity_type_string of this ActivityProperties.  # noqa: E501


        :return: The activity_type_string of this ActivityProperties.  # noqa: E501
        :rtype: str
        """
        return self._activity_type_string

    @activity_type_string.setter
    def activity_type_string(self, activity_type_string):
        """Sets the activity_type_string of this ActivityProperties.


        :param activity_type_string: The activity_type_string of this ActivityProperties.  # noqa: E501
        :type: str
        """
        if activity_type_string is None:
            raise ValueError("Invalid value for `activity_type_string`, must not be `None`")  # noqa: E501

        self._activity_type_string = activity_type_string

    @property
    def area_name(self):
        """Gets the area_name of this ActivityProperties.  # noqa: E501


        :return: The area_name of this ActivityProperties.  # noqa: E501
        :rtype: str
        """
        return self._area_name

    @area_name.setter
    def area_name(self, area_name):
        """Sets the area_name of this ActivityProperties.


        :param area_name: The area_name of this ActivityProperties.  # noqa: E501
        :type: str
        """
        if area_name is None:
            raise ValueError("Invalid value for `area_name`, must not be `None`")  # noqa: E501

        self._area_name = area_name

    @property
    def cancelled(self):
        """Gets the cancelled of this ActivityProperties.  # noqa: E501


        :return: The cancelled of this ActivityProperties.  # noqa: E501
        :rtype: bool
        """
        return self._cancelled

    @cancelled.setter
    def cancelled(self, cancelled):
        """Sets the cancelled of this ActivityProperties.


        :param cancelled: The cancelled of this ActivityProperties.  # noqa: E501
        :type: bool
        """
        if cancelled is None:
            raise ValueError("Invalid value for `cancelled`, must not be `None`")  # noqa: E501

        self._cancelled = cancelled

    @property
    def end_date(self):
        """Gets the end_date of this ActivityProperties.  # noqa: E501


        :return: The end_date of this ActivityProperties.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this ActivityProperties.


        :param end_date: The end_date of this ActivityProperties.  # noqa: E501
        :type: datetime
        """
        if end_date is None:
            raise ValueError("Invalid value for `end_date`, must not be `None`")  # noqa: E501

        self._end_date = end_date

    @property
    def street_name(self):
        """Gets the street_name of this ActivityProperties.  # noqa: E501


        :return: The street_name of this ActivityProperties.  # noqa: E501
        :rtype: str
        """
        return self._street_name

    @street_name.setter
    def street_name(self, street_name):
        """Sets the street_name of this ActivityProperties.


        :param street_name: The street_name of this ActivityProperties.  # noqa: E501
        :type: str
        """
        if street_name is None:
            raise ValueError("Invalid value for `street_name`, must not be `None`")  # noqa: E501

        self._street_name = street_name

    @property
    def start_date(self):
        """Gets the start_date of this ActivityProperties.  # noqa: E501


        :return: The start_date of this ActivityProperties.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this ActivityProperties.


        :param start_date: The start_date of this ActivityProperties.  # noqa: E501
        :type: datetime
        """
        if start_date is None:
            raise ValueError("Invalid value for `start_date`, must not be `None`")  # noqa: E501

        self._start_date = start_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ActivityProperties, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActivityProperties):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WorkHistoryResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'pagination': 'PaginationDetails',
        'rows': 'list[WorkHistorySummaryResponse]'
    }

    attribute_map = {
        'pagination': 'pagination',
        'rows': 'rows'
    }

    def __init__(self, pagination=None, rows=None):  # noqa: E501
        """WorkHistoryResponse - a model defined in Swagger"""  # noqa: E501
        self._pagination = None
        self._rows = None
        self.discriminator = None
        self.pagination = pagination
        self.rows = rows

    @property
    def pagination(self):
        """Gets the pagination of this WorkHistoryResponse.  # noqa: E501


        :return: The pagination of this WorkHistoryResponse.  # noqa: E501
        :rtype: PaginationDetails
        """
        return self._pagination

    @pagination.setter
    def pagination(self, pagination):
        """Sets the pagination of this WorkHistoryResponse.


        :param pagination: The pagination of this WorkHistoryResponse.  # noqa: E501
        :type: PaginationDetails
        """
        if pagination is None:
            raise ValueError("Invalid value for `pagination`, must not be `None`")  # noqa: E501

        self._pagination = pagination

    @property
    def rows(self):
        """Gets the rows of this WorkHistoryResponse.  # noqa: E501


        :return: The rows of this WorkHistoryResponse.  # noqa: E501
        :rtype: list[WorkHistorySummaryResponse]
        """
        return self._rows

    @rows.setter
    def rows(self, rows):
        """Sets the rows of this WorkHistoryResponse.


        :param rows: The rows of this WorkHistoryResponse.  # noqa: E501
        :type: list[WorkHistorySummaryResponse]
        """
        if rows is None:
            raise ValueError("Invalid value for `rows`, must not be `None`")  # noqa: E501

        self._rows = rows

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkHistoryResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkHistoryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ReinstatementResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'reinstatement_reference_number': 'str',
        'permit_reference_number': 'str',
        'reinstatement_status': 'ReinstatementStatusResponse',
        'reinstatement_status_string': 'str',
        'reinstatement_date': 'datetime',
        'depth': 'float',
        'length': 'float',
        'width': 'float',
        'reinstatement_coordinates': 'object',
        'secondary_reinstatement_coordinates': 'object',
        'location_description': 'str',
        'end_date': 'datetime',
        'date_created': 'datetime',
        'date_modified': 'datetime',
        'location_types': 'list[LocationTypeResponse]',
        'location_types_string': 'list[str]',
        'reinstatement_evidence': 'bool',
        'files': 'list[FileSummaryResponse]',
        'number_of_holes': 'float',
        'is_active_reinstatement': 'bool',
        'response_to_remedial_works': 'bool',
        'base_courses_affected': 'bool'
    }

    attribute_map = {
        'reinstatement_reference_number': 'reinstatement_reference_number',
        'permit_reference_number': 'permit_reference_number',
        'reinstatement_status': 'reinstatement_status',
        'reinstatement_status_string': 'reinstatement_status_string',
        'reinstatement_date': 'reinstatement_date',
        'depth': 'depth',
        'length': 'length',
        'width': 'width',
        'reinstatement_coordinates': 'reinstatement_coordinates',
        'secondary_reinstatement_coordinates': 'secondary_reinstatement_coordinates',
        'location_description': 'location_description',
        'end_date': 'end_date',
        'date_created': 'date_created',
        'date_modified': 'date_modified',
        'location_types': 'location_types',
        'location_types_string': 'location_types_string',
        'reinstatement_evidence': 'reinstatement_evidence',
        'files': 'files',
        'number_of_holes': 'number_of_holes',
        'is_active_reinstatement': 'is_active_reinstatement',
        'response_to_remedial_works': 'response_to_remedial_works',
        'base_courses_affected': 'base_courses_affected'
    }

    def __init__(self, reinstatement_reference_number=None, permit_reference_number=None, reinstatement_status=None, reinstatement_status_string=None, reinstatement_date=None, depth=None, length=None, width=None, reinstatement_coordinates=None, secondary_reinstatement_coordinates=None, location_description=None, end_date=None, date_created=None, date_modified=None, location_types=None, location_types_string=None, reinstatement_evidence=None, files=None, number_of_holes=None, is_active_reinstatement=None, response_to_remedial_works=None, base_courses_affected=None):  # noqa: E501
        """ReinstatementResponse - a model defined in Swagger"""  # noqa: E501
        self._reinstatement_reference_number = None
        self._permit_reference_number = None
        self._reinstatement_status = None
        self._reinstatement_status_string = None
        self._reinstatement_date = None
        self._depth = None
        self._length = None
        self._width = None
        self._reinstatement_coordinates = None
        self._secondary_reinstatement_coordinates = None
        self._location_description = None
        self._end_date = None
        self._date_created = None
        self._date_modified = None
        self._location_types = None
        self._location_types_string = None
        self._reinstatement_evidence = None
        self._files = None
        self._number_of_holes = None
        self._is_active_reinstatement = None
        self._response_to_remedial_works = None
        self._base_courses_affected = None
        self.discriminator = None
        self.reinstatement_reference_number = reinstatement_reference_number
        if permit_reference_number is not None:
            self.permit_reference_number = permit_reference_number
        self.reinstatement_status = reinstatement_status
        self.reinstatement_status_string = reinstatement_status_string
        if reinstatement_date is not None:
            self.reinstatement_date = reinstatement_date
        if depth is not None:
            self.depth = depth
        if length is not None:
            self.length = length
        if width is not None:
            self.width = width
        self.reinstatement_coordinates = reinstatement_coordinates
        if secondary_reinstatement_coordinates is not None:
            self.secondary_reinstatement_coordinates = secondary_reinstatement_coordinates
        self.location_description = location_description
        if end_date is not None:
            self.end_date = end_date
        self.date_created = date_created
        self.date_modified = date_modified
        self.location_types = location_types
        self.location_types_string = location_types_string
        self.reinstatement_evidence = reinstatement_evidence
        if files is not None:
            self.files = files
        if number_of_holes is not None:
            self.number_of_holes = number_of_holes
        self.is_active_reinstatement = is_active_reinstatement
        if response_to_remedial_works is not None:
            self.response_to_remedial_works = response_to_remedial_works
        if base_courses_affected is not None:
            self.base_courses_affected = base_courses_affected

    @property
    def reinstatement_reference_number(self):
        """Gets the reinstatement_reference_number of this ReinstatementResponse.  # noqa: E501


        :return: The reinstatement_reference_number of this ReinstatementResponse.  # noqa: E501
        :rtype: str
        """
        return self._reinstatement_reference_number

    @reinstatement_reference_number.setter
    def reinstatement_reference_number(self, reinstatement_reference_number):
        """Sets the reinstatement_reference_number of this ReinstatementResponse.


        :param reinstatement_reference_number: The reinstatement_reference_number of this ReinstatementResponse.  # noqa: E501
        :type: str
        """
        if reinstatement_reference_number is None:
            raise ValueError("Invalid value for `reinstatement_reference_number`, must not be `None`")  # noqa: E501

        self._reinstatement_reference_number = reinstatement_reference_number

    @property
    def permit_reference_number(self):
        """Gets the permit_reference_number of this ReinstatementResponse.  # noqa: E501


        :return: The permit_reference_number of this ReinstatementResponse.  # noqa: E501
        :rtype: str
        """
        return self._permit_reference_number

    @permit_reference_number.setter
    def permit_reference_number(self, permit_reference_number):
        """Sets the permit_reference_number of this ReinstatementResponse.


        :param permit_reference_number: The permit_reference_number of this ReinstatementResponse.  # noqa: E501
        :type: str
        """

        self._permit_reference_number = permit_reference_number

    @property
    def reinstatement_status(self):
        """Gets the reinstatement_status of this ReinstatementResponse.  # noqa: E501


        :return: The reinstatement_status of this ReinstatementResponse.  # noqa: E501
        :rtype: ReinstatementStatusResponse
        """
        return self._reinstatement_status

    @reinstatement_status.setter
    def reinstatement_status(self, reinstatement_status):
        """Sets the reinstatement_status of this ReinstatementResponse.


        :param reinstatement_status: The reinstatement_status of this ReinstatementResponse.  # noqa: E501
        :type: ReinstatementStatusResponse
        """
        if reinstatement_status is None:
            raise ValueError("Invalid value for `reinstatement_status`, must not be `None`")  # noqa: E501

        self._reinstatement_status = reinstatement_status

    @property
    def reinstatement_status_string(self):
        """Gets the reinstatement_status_string of this ReinstatementResponse.  # noqa: E501


        :return: The reinstatement_status_string of this ReinstatementResponse.  # noqa: E501
        :rtype: str
        """
        return self._reinstatement_status_string

    @reinstatement_status_string.setter
    def reinstatement_status_string(self, reinstatement_status_string):
        """Sets the reinstatement_status_string of this ReinstatementResponse.


        :param reinstatement_status_string: The reinstatement_status_string of this ReinstatementResponse.  # noqa: E501
        :type: str
        """
        if reinstatement_status_string is None:
            raise ValueError("Invalid value for `reinstatement_status_string`, must not be `None`")  # noqa: E501

        self._reinstatement_status_string = reinstatement_status_string

    @property
    def reinstatement_date(self):
        """Gets the reinstatement_date of this ReinstatementResponse.  # noqa: E501


        :return: The reinstatement_date of this ReinstatementResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._reinstatement_date

    @reinstatement_date.setter
    def reinstatement_date(self, reinstatement_date):
        """Sets the reinstatement_date of this ReinstatementResponse.


        :param reinstatement_date: The reinstatement_date of this ReinstatementResponse.  # noqa: E501
        :type: datetime
        """

        self._reinstatement_date = reinstatement_date

    @property
    def depth(self):
        """Gets the depth of this ReinstatementResponse.  # noqa: E501


        :return: The depth of this ReinstatementResponse.  # noqa: E501
        :rtype: float
        """
        return self._depth

    @depth.setter
    def depth(self, depth):
        """Sets the depth of this ReinstatementResponse.


        :param depth: The depth of this ReinstatementResponse.  # noqa: E501
        :type: float
        """

        self._depth = depth

    @property
    def length(self):
        """Gets the length of this ReinstatementResponse.  # noqa: E501


        :return: The length of this ReinstatementResponse.  # noqa: E501
        :rtype: float
        """
        return self._length

    @length.setter
    def length(self, length):
        """Sets the length of this ReinstatementResponse.


        :param length: The length of this ReinstatementResponse.  # noqa: E501
        :type: float
        """

        self._length = length

    @property
    def width(self):
        """Gets the width of this ReinstatementResponse.  # noqa: E501


        :return: The width of this ReinstatementResponse.  # noqa: E501
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this ReinstatementResponse.


        :param width: The width of this ReinstatementResponse.  # noqa: E501
        :type: float
        """

        self._width = width

    @property
    def reinstatement_coordinates(self):
        """Gets the reinstatement_coordinates of this ReinstatementResponse.  # noqa: E501


        :return: The reinstatement_coordinates of this ReinstatementResponse.  # noqa: E501
        :rtype: object
        """
        return self._reinstatement_coordinates

    @reinstatement_coordinates.setter
    def reinstatement_coordinates(self, reinstatement_coordinates):
        """Sets the reinstatement_coordinates of this ReinstatementResponse.


        :param reinstatement_coordinates: The reinstatement_coordinates of this ReinstatementResponse.  # noqa: E501
        :type: object
        """
        if reinstatement_coordinates is None:
            raise ValueError("Invalid value for `reinstatement_coordinates`, must not be `None`")  # noqa: E501

        self._reinstatement_coordinates = reinstatement_coordinates

    @property
    def secondary_reinstatement_coordinates(self):
        """Gets the secondary_reinstatement_coordinates of this ReinstatementResponse.  # noqa: E501


        :return: The secondary_reinstatement_coordinates of this ReinstatementResponse.  # noqa: E501
        :rtype: object
        """
        return self._secondary_reinstatement_coordinates

    @secondary_reinstatement_coordinates.setter
    def secondary_reinstatement_coordinates(self, secondary_reinstatement_coordinates):
        """Sets the secondary_reinstatement_coordinates of this ReinstatementResponse.


        :param secondary_reinstatement_coordinates: The secondary_reinstatement_coordinates of this ReinstatementResponse.  # noqa: E501
        :type: object
        """

        self._secondary_reinstatement_coordinates = secondary_reinstatement_coordinates

    @property
    def location_description(self):
        """Gets the location_description of this ReinstatementResponse.  # noqa: E501


        :return: The location_description of this ReinstatementResponse.  # noqa: E501
        :rtype: str
        """
        return self._location_description

    @location_description.setter
    def location_description(self, location_description):
        """Sets the location_description of this ReinstatementResponse.


        :param location_description: The location_description of this ReinstatementResponse.  # noqa: E501
        :type: str
        """
        if location_description is None:
            raise ValueError("Invalid value for `location_description`, must not be `None`")  # noqa: E501

        self._location_description = location_description

    @property
    def end_date(self):
        """Gets the end_date of this ReinstatementResponse.  # noqa: E501


        :return: The end_date of this ReinstatementResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this ReinstatementResponse.


        :param end_date: The end_date of this ReinstatementResponse.  # noqa: E501
        :type: datetime
        """

        self._end_date = end_date

    @property
    def date_created(self):
        """Gets the date_created of this ReinstatementResponse.  # noqa: E501


        :return: The date_created of this ReinstatementResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this ReinstatementResponse.


        :param date_created: The date_created of this ReinstatementResponse.  # noqa: E501
        :type: datetime
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def date_modified(self):
        """Gets the date_modified of this ReinstatementResponse.  # noqa: E501


        :return: The date_modified of this ReinstatementResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """Sets the date_modified of this ReinstatementResponse.


        :param date_modified: The date_modified of this ReinstatementResponse.  # noqa: E501
        :type: datetime
        """
        if date_modified is None:
            raise ValueError("Invalid value for `date_modified`, must not be `None`")  # noqa: E501

        self._date_modified = date_modified

    @property
    def location_types(self):
        """Gets the location_types of this ReinstatementResponse.  # noqa: E501


        :return: The location_types of this ReinstatementResponse.  # noqa: E501
        :rtype: list[LocationTypeResponse]
        """
        return self._location_types

    @location_types.setter
    def location_types(self, location_types):
        """Sets the location_types of this ReinstatementResponse.


        :param location_types: The location_types of this ReinstatementResponse.  # noqa: E501
        :type: list[LocationTypeResponse]
        """
        if location_types is None:
            raise ValueError("Invalid value for `location_types`, must not be `None`")  # noqa: E501

        self._location_types = location_types

    @property
    def location_types_string(self):
        """Gets the location_types_string of this ReinstatementResponse.  # noqa: E501


        :return: The location_types_string of this ReinstatementResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._location_types_string

    @location_types_string.setter
    def location_types_string(self, location_types_string):
        """Sets the location_types_string of this ReinstatementResponse.


        :param location_types_string: The location_types_string of this ReinstatementResponse.  # noqa: E501
        :type: list[str]
        """
        if location_types_string is None:
            raise ValueError("Invalid value for `location_types_string`, must not be `None`")  # noqa: E501

        self._location_types_string = location_types_string

    @property
    def reinstatement_evidence(self):
        """Gets the reinstatement_evidence of this ReinstatementResponse.  # noqa: E501


        :return: The reinstatement_evidence of this ReinstatementResponse.  # noqa: E501
        :rtype: bool
        """
        return self._reinstatement_evidence

    @reinstatement_evidence.setter
    def reinstatement_evidence(self, reinstatement_evidence):
        """Sets the reinstatement_evidence of this ReinstatementResponse.


        :param reinstatement_evidence: The reinstatement_evidence of this ReinstatementResponse.  # noqa: E501
        :type: bool
        """
        if reinstatement_evidence is None:
            raise ValueError("Invalid value for `reinstatement_evidence`, must not be `None`")  # noqa: E501

        self._reinstatement_evidence = reinstatement_evidence

    @property
    def files(self):
        """Gets the files of this ReinstatementResponse.  # noqa: E501


        :return: The files of this ReinstatementResponse.  # noqa: E501
        :rtype: list[FileSummaryResponse]
        """
        return self._files

    @files.setter
    def files(self, files):
        """Sets the files of this ReinstatementResponse.


        :param files: The files of this ReinstatementResponse.  # noqa: E501
        :type: list[FileSummaryResponse]
        """

        self._files = files

    @property
    def number_of_holes(self):
        """Gets the number_of_holes of this ReinstatementResponse.  # noqa: E501


        :return: The number_of_holes of this ReinstatementResponse.  # noqa: E501
        :rtype: float
        """
        return self._number_of_holes

    @number_of_holes.setter
    def number_of_holes(self, number_of_holes):
        """Sets the number_of_holes of this ReinstatementResponse.


        :param number_of_holes: The number_of_holes of this ReinstatementResponse.  # noqa: E501
        :type: float
        """

        self._number_of_holes = number_of_holes

    @property
    def is_active_reinstatement(self):
        """Gets the is_active_reinstatement of this ReinstatementResponse.  # noqa: E501


        :return: The is_active_reinstatement of this ReinstatementResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_active_reinstatement

    @is_active_reinstatement.setter
    def is_active_reinstatement(self, is_active_reinstatement):
        """Sets the is_active_reinstatement of this ReinstatementResponse.


        :param is_active_reinstatement: The is_active_reinstatement of this ReinstatementResponse.  # noqa: E501
        :type: bool
        """
        if is_active_reinstatement is None:
            raise ValueError("Invalid value for `is_active_reinstatement`, must not be `None`")  # noqa: E501

        self._is_active_reinstatement = is_active_reinstatement

    @property
    def response_to_remedial_works(self):
        """Gets the response_to_remedial_works of this ReinstatementResponse.  # noqa: E501


        :return: The response_to_remedial_works of this ReinstatementResponse.  # noqa: E501
        :rtype: bool
        """
        return self._response_to_remedial_works

    @response_to_remedial_works.setter
    def response_to_remedial_works(self, response_to_remedial_works):
        """Sets the response_to_remedial_works of this ReinstatementResponse.


        :param response_to_remedial_works: The response_to_remedial_works of this ReinstatementResponse.  # noqa: E501
        :type: bool
        """

        self._response_to_remedial_works = response_to_remedial_works

    @property
    def base_courses_affected(self):
        """Gets the base_courses_affected of this ReinstatementResponse.  # noqa: E501


        :return: The base_courses_affected of this ReinstatementResponse.  # noqa: E501
        :rtype: bool
        """
        return self._base_courses_affected

    @base_courses_affected.setter
    def base_courses_affected(self, base_courses_affected):
        """Sets the base_courses_affected of this ReinstatementResponse.


        :param base_courses_affected: The base_courses_affected of this ReinstatementResponse.  # noqa: E501
        :type: bool
        """

        self._base_courses_affected = base_courses_affected

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReinstatementResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReinstatementResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
